@@ -45,17 +45,21 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
+
+#include <libxfce4util/libxfce4util.h>
+
 #include "globaltime.h"
 #include "../src/orage-i18n.h"
 
 
 #define NAME_VERSION "Global Time (2.2)"
 
+#define GLOBALTIME_RAISE "_XFCE_GLOBALTIME_RAISE"
 
 global_times_struct clocks;
 
 char *attr_underline[] = 
-    { "no underline", "single", "double", "low", "END" } ;
+    { N_("no underline"), N_("single"), N_("double"), N_("low"), "END" } ;
 
 
 static struct tm *get_time(const gchar *tz)
@@ -64,10 +68,10 @@ static struct tm *get_time(const gchar *tz)
     static struct tm now;
     static char env_tz[256];
 
-    /*
+#if 0
     setenv("TZ", tz, 1);
-    */
-    g_snprintf(env_tz, 256, "TZ=%s", tz);
+#endif
+    g_snprintf(env_tz, sizeof (env_tz), "TZ=%s", tz);
     putenv(env_tz);
     tzset();
     if (clocks.time_adj_act) {
@@ -83,23 +87,32 @@ static struct tm *get_time(const gchar *tz)
 
 static gboolean global_time_active_already(GdkAtom *atom)
 {
+    XEvent xevent;
     Window xwindow;
-    GdkEventClient gev; 
+    Display *display;
+    gchar *event;
 
-    *atom = gdk_atom_intern("_XFCE_GLOBALTIME_RUNNING", FALSE);
-    xwindow = XGetSelectionOwner(GDK_DISPLAY(), gdk_x11_atom_to_xatom(*atom));
-    if (xwindow != None) { /* real owner found; must be us. Let's go visible */
-/* DOES NOT WORK: if ((window = gdk_selection_owner_get(atom)) != NULL) { */
-        gev.type = GDK_CLIENT_EVENT;
-        gev.window = NULL;
-        gev.send_event = TRUE;
-        gev.message_type = gdk_atom_intern ("_XFCE_GLOBALTIME_RAISE", FALSE);
-        gev.data_format = 8; 
-        if (gdk_event_send_client_message ((GdkEvent *) &gev
-                    , (GdkNativeWindow) xwindow))
-            g_message(_("Raising GlobalTime window..."));
+    *atom = gdk_atom_intern (GLOBALTIME_RUNNING, FALSE);
+    display = gdk_x11_get_default_xdisplay ();
+    xwindow = XGetSelectionOwner (display, gdk_x11_atom_to_xatom (*atom));
+
+    if (xwindow != None)
+    {
+        /* Real owner found; must be us. Let's go visible. */
+        event = GLOBALTIME_RAISE;
+        xevent.xclient.type = ClientMessage;
+        xevent.xclient.format = 8;
+        xevent.xclient.display = display;
+        xevent.xclient.window = xwindow;
+        xevent.xclient.send_event = TRUE;
+        xevent.xclient.message_type = XInternAtom (display, event, FALSE);
+
+        if (XSendEvent (display, xwindow, FALSE, NoEventMask, &xevent))
+            g_debug ("Raising GlobalTime window");
         else
-            g_warning(_("GlobalTime window raise failed"));
+            g_warning ("GlobalTime window raise failed");
+
+        (void)XFlush (display);
         return(TRUE); 
     }
     else
@@ -113,34 +126,50 @@ static void raise_window(void)
     gtk_window_set_decorated(GTK_WINDOW(clocks.window), clocks.decorations);
     gtk_window_move(GTK_WINDOW(clocks.window), clocks.x, clocks.y);
     gtk_window_stick(GTK_WINDOW(clocks.window));
-    window = GTK_WIDGET(clocks.window)->window;
+    window = gtk_widget_get_window (GTK_WIDGET(clocks.window));
     gdk_x11_window_set_user_time(window, gdk_x11_get_server_time(window));
     gtk_widget_show(clocks.window);
     gtk_window_present(GTK_WINDOW(clocks.window));
 }
 
-static gboolean client_message_received(GtkWidget *widget
-            , GdkEventClient *event, gpointer user_data)
+static GdkFilterReturn
+client_message_filter (GdkXEvent *gdkxevent,
+                       G_GNUC_UNUSED GdkEvent *event,
+                       G_GNUC_UNUSED gpointer data)
 {
-    if (event->message_type == 
-            gdk_atom_intern("_XFCE_GLOBALTIME_RAISE", FALSE)) {
-        raise_window();
-        return(TRUE);
+    XClientMessageEvent *evt;
+    const XEvent *xevent = (const XEvent *)gdkxevent;
+
+    if (xevent->type != ClientMessage)
+        return GDK_FILTER_CONTINUE;
+
+    evt = (XClientMessageEvent *)gdkxevent;
+
+    if (evt->message_type ==
+            XInternAtom (evt->display, GLOBALTIME_RAISE, FALSE))
+    {
+        g_debug ("received '" GLOBALTIME_RAISE "' event");
+        raise_window ();
+        return GDK_FILTER_REMOVE;
     }
-    else if (event->message_type ==
-            gdk_atom_intern("_XFCE_GLOBALTIME_TOGGLE_HERE", FALSE)) {
-        if (GTK_WIDGET_VISIBLE(clocks.window)) {
-            gtk_widget_hide(clocks.window);
-            return(TRUE);
-        }
-        raise_window();
-        return(TRUE);
+
+    else if (evt->message_type ==
+             XInternAtom (evt->display, GLOBALTIME_TOGGLE, FALSE))
+    {
+        g_debug ("received '" GLOBALTIME_TOGGLE "' event");
+        if (gtk_widget_get_visible (clocks.window))
+            gtk_widget_hide (clocks.window);
+        else
+            raise_window();
+
+        return GDK_FILTER_REMOVE;
     }
-                                                                                
-    return(FALSE);
+
+    return GDK_FILTER_CONTINUE;
 }
 
-static gboolean clock_button_pressed(GtkWidget *widget, GdkEventButton *event
+static gboolean clock_button_pressed (GtkWidget *widget,
+                                      G_GNUC_UNUSED GdkEventButton *event
         , clock_struct *clockp)
 {
     return(clock_parameters(widget, clockp));
@@ -208,74 +237,110 @@ static void show_clock_format_time(clock_struct *clockp)
     }
 }
 
+static void gt_label_set_font (GtkLabel *label, const GString *font_str)
+{
+    PangoFontDescription *font;
+    PangoAttrList *attrlist;
+    PangoAttribute *attr;
+
+    font = pango_font_description_from_string (font_str->str);
+    attr = pango_attr_font_desc_new (font);
+    pango_font_description_free (font);
+    attrlist = pango_attr_list_new ();
+    pango_attr_list_insert (attrlist, attr);
+    gtk_label_set_attributes (label, attrlist);
+    pango_attr_list_unref (attrlist);
+}
+
+static void gt_set_background_color (GtkWidget *widget, const GdkRGBA *color)
+{
+    /* Deprecation warnings are disabled, as it is not reasonable to change
+     * current implementation to CSS. But if widget colour changing through CSS
+     * is still needed, then the general idea is following:
+     * provider = Gtk.CssProvider()
+     * provider.load_from_data(some_css_fragment)
+     * widget.get_style_context().add_provider(provider,
+     *                          Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
+     *
+     * Once you want to reset the widget's style, you call:
+     * widget.get_style_context().remove_provider(provider)
+     */
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+    gtk_widget_override_background_color (widget, GTK_STATE_FLAG_NORMAL, color);
+    G_GNUC_END_IGNORE_DEPRECATIONS
+}
+
+static void gt_set_foreground_color (GtkWidget *widget, const GdkRGBA *color)
+{
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+    gtk_widget_override_color (widget, GTK_STATE_FLAG_NORMAL, color);
+    G_GNUC_END_IGNORE_DEPRECATIONS
+}
+
 static void show_clock_format_clock(clock_struct *clockp)
 {
     gchar tmp[100];
-    PangoFontDescription *font;
 
 /*********** Clock Name font ***********/
     if (clockp->clock_attr.name_font_modified) {
-        font = pango_font_description_from_string(
-                clockp->clock_attr.name_font->str);
-        gtk_widget_modify_font(clockp->name_label, font);
-        pango_font_description_free(font);
+        gt_label_set_font (GTK_LABEL (clockp->name_label),
+                           clockp->clock_attr.name_font);
     }
     else if (clocks.clock_default_attr.name_font_modified) {
-        font = pango_font_description_from_string(
-                clocks.clock_default_attr.name_font->str);
-        gtk_widget_modify_font(clockp->name_label, font);
-        pango_font_description_free(font);
+        gt_label_set_font (GTK_LABEL (clockp->name_label),
+                           clocks.clock_default_attr.name_font);
     }
     else 
-        gtk_widget_modify_font(clockp->name_label, NULL);
+        gtk_label_set_attributes (GTK_LABEL (clockp->name_label), NULL);
 
 /*********** Clock Time font ***********/
     if (clockp->clock_attr.time_font_modified) {
-        font = pango_font_description_from_string(
-                clockp->clock_attr.time_font->str);
-        gtk_widget_modify_font(clockp->time_label, font);
-        pango_font_description_free(font);
+        gt_label_set_font (GTK_LABEL (clockp->time_label),
+                           clockp->clock_attr.time_font);
     }
     else if (clocks.clock_default_attr.time_font_modified) {
-        font = pango_font_description_from_string(
-                clocks.clock_default_attr.time_font->str);
-        gtk_widget_modify_font(clockp->time_label, font);
-        pango_font_description_free(font);
+        gt_label_set_font (GTK_LABEL (clockp->time_label),
+                           clocks.clock_default_attr.time_font);
     }
     else 
-        gtk_widget_modify_font(clockp->time_label, NULL);
+        gtk_label_set_attributes (GTK_LABEL (clockp->time_label), NULL);
 
 /*********** Clock background ***********/
     if (clockp->clock_attr.clock_bg_modified)
-        gtk_widget_modify_bg(clockp->clock_ebox, GTK_STATE_NORMAL
-                , clockp->clock_attr.clock_bg);
+    {
+        gt_set_background_color (clockp->clock_ebox,
+                                 clockp->clock_attr.clock_bg);
+    }
     else if (clocks.clock_default_attr.clock_bg_modified)
-        gtk_widget_modify_bg(clockp->clock_ebox, GTK_STATE_NORMAL
-                , clocks.clock_default_attr.clock_bg);
+    {
+        gt_set_background_color (clockp->clock_ebox,
+                                 clocks.clock_default_attr.clock_bg);
+    }
     else
-        gtk_widget_modify_bg(clockp->clock_ebox, GTK_STATE_NORMAL, NULL);
+        gt_set_background_color (clockp->clock_ebox, NULL);
 
 /*********** Clock foreground ***********/
     if (clockp->clock_attr.clock_fg_modified) {
-        gtk_widget_modify_fg(clockp->name_label, GTK_STATE_NORMAL
-                , clockp->clock_attr.clock_fg);
-        gtk_widget_modify_fg(clockp->time_label, GTK_STATE_NORMAL
-                , clockp->clock_attr.clock_fg);
+        gt_set_foreground_color (clockp->name_label,
+                                 clockp->clock_attr.clock_fg);
+        gt_set_foreground_color (clockp->time_label,
+                                 clockp->clock_attr.clock_fg);
     }
     else if (clocks.clock_default_attr.clock_fg_modified) {
-        gtk_widget_modify_fg(clockp->name_label, GTK_STATE_NORMAL
-                , clocks.clock_default_attr.clock_fg);
-        gtk_widget_modify_fg(clockp->time_label, GTK_STATE_NORMAL
-                , clocks.clock_default_attr.clock_fg);
+        gt_set_foreground_color (clockp->name_label,
+                                 clocks.clock_default_attr.clock_fg);
+        gt_set_foreground_color (clockp->time_label,
+                                 clocks.clock_default_attr.clock_fg);
     }
     else {
-        gtk_widget_modify_fg(clockp->time_label, GTK_STATE_NORMAL, NULL);
-        gtk_widget_modify_fg(clockp->name_label, GTK_STATE_NORMAL, NULL);
+        gt_set_foreground_color (clockp->time_label, NULL);
+        gt_set_foreground_color (clockp->name_label, NULL);
     }
 
 /*********** timezone tooltip ***********/
-    sprintf(tmp, _("%s\nclick to modify clock"), clockp->tz->str);
-    gtk_tooltips_set_tip(clocks.tips, clockp->clock_ebox, tmp, NULL);
+    g_snprintf (tmp, sizeof (tmp), _("%s\nclick to modify clock"),
+                clockp->tz->str);
+    gtk_widget_set_tooltip_text(clockp->clock_ebox, tmp);
 
 /*********** clock size even or varying */
     gtk_box_set_homogeneous(GTK_BOX(clocks.clocks_hbox), clocks.expand);
@@ -294,15 +359,15 @@ static void show_clock_format_clock(clock_struct *clockp)
 
 void show_clock(clock_struct *clockp, gint *pos)
 {
-    clockp->clock_hbox = gtk_hbox_new(FALSE, 0);
+    clockp->clock_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_pack_start(GTK_BOX(clocks.clocks_hbox), clockp->clock_hbox
                         , clocks.expand, clocks.expand, 0);
     if (*pos !=- 1) /* -1=to the end (default) */
-        gtk_box_reorder_child(GTK_BOX(clocks.clocks_hbox)
-                        , clockp->clock_hbox, *pos);
+        gtk_box_reorder_child(GTK_BOX(clocks.clocks_hbox), clockp->clock_hbox,
+                              *pos);
     gtk_widget_show(clockp->clock_hbox);
 
-    clockp->clock_separator = gtk_vseparator_new();
+    clockp->clock_separator = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
     gtk_box_pack_start(GTK_BOX(clockp->clock_hbox)
                     , clockp->clock_separator, FALSE, FALSE, 0);
     gtk_widget_show(clockp->clock_separator);
@@ -313,8 +378,7 @@ void show_clock(clock_struct *clockp, gint *pos)
     g_signal_connect(G_OBJECT(clockp->clock_ebox), "button_press_event"
                     , G_CALLBACK(clock_button_pressed), clockp);
     gtk_widget_show(clockp->clock_ebox);
-
-    clockp->clock_vbox = gtk_vbox_new(FALSE, 1);
+    clockp->clock_vbox = gtk_grid_new ();
     gtk_container_set_border_width(GTK_CONTAINER(clockp->clock_vbox), 1);
     gtk_container_add(GTK_CONTAINER(clockp->clock_ebox), clockp->clock_vbox);
     gtk_widget_show(clockp->clock_vbox);
@@ -322,15 +386,15 @@ void show_clock(clock_struct *clockp, gint *pos)
 /*********** Clock Name ***********/
     clockp->name_label = gtk_label_new(NULL);
     show_clock_format_name(clockp);
-    gtk_box_pack_start(GTK_BOX(clockp->clock_vbox), clockp->name_label
-            , FALSE, FALSE, 0);
+    gtk_grid_attach_next_to (GTK_GRID (clockp->clock_vbox), clockp->name_label,
+                             NULL, GTK_POS_BOTTOM, 1, 1);
     gtk_widget_show(clockp->name_label);
 
 /*********** Timezone and actual time ***********/
     clockp->time_label = gtk_label_new(NULL);
     show_clock_format_time(clockp);
-    gtk_box_pack_start(GTK_BOX(clockp->clock_vbox), clockp->time_label
-            , FALSE, FALSE, 0);
+    gtk_grid_attach_next_to (GTK_GRID (clockp->clock_vbox), clockp->time_label,
+                             NULL, GTK_POS_BOTTOM, 1, 1);
     gtk_widget_show(clockp->time_label);
 
 /*********** font and color ***************/
@@ -339,7 +403,7 @@ void show_clock(clock_struct *clockp, gint *pos)
 
 
 static gboolean preferences_button_pressed(GtkWidget *widget
-        , GdkEventButton *event, gpointer dummy)
+        , GdkEventButton *event, G_GNUC_UNUSED gpointer dummy)
 {
     struct tm *now;
 
@@ -390,17 +454,27 @@ static void add_default_clock(void)
     write_file();
 }
 
-static void upd_clock(clock_struct *clockp)
+static void upd_clock (clock_struct *clockp, G_GNUC_UNUSED gpointer user_data)
 {
     struct tm *now;
 
     now = get_time(clockp->tz->str);
     if (clocks.local_mday == now->tm_mday) 
-        sprintf(clocks.time_now, "%02d:%02d", now->tm_hour, now->tm_min);
+    {
+        g_snprintf (clocks.time_now, sizeof (clocks.time_now), "%02d:%02d",
+                    now->tm_hour, now->tm_min);
+    }
     else if (clocks.local_mday > now->tm_mday) 
-        sprintf(clocks.time_now, "%02d:%02d-", now->tm_hour, now->tm_min);
+    {
+        g_snprintf (clocks.time_now, sizeof (clocks.time_now), "%02d:%02d-",
+                    now->tm_hour, now->tm_min);
+    }
     else
-        sprintf(clocks.time_now, "%02d:%02d+", now->tm_hour, now->tm_min);
+    {
+        g_snprintf (clocks.time_now, sizeof (clocks.time_now), "%02d:%02d+",
+                    now->tm_hour, now->tm_min);
+    }
+
     show_clock_format_time(clockp);
     if (clocks.modified > 0) {
         show_clock_format_name(clockp);
@@ -408,7 +482,7 @@ static void upd_clock(clock_struct *clockp)
     }
 }
 
-static gboolean upd_clocks(void)
+static gboolean upd_clocks (G_GNUC_UNUSED gpointer user_data)
 {
     struct tm *now;
     gint secs_now;
@@ -432,15 +506,16 @@ static gboolean upd_clocks(void)
         /* minute changed => need to update visible clocks */
         g_list_foreach(clocks.clock_list, (GFunc) upd_clock, NULL);
     clocks.previous_secs = secs_now;
+
     return(TRUE);
 }
 
-static void adj_hh_changed(GtkSpinButton *cb, gpointer user_data)
+static void adj_hh_changed (GtkSpinButton *cb, G_GNUC_UNUSED gpointer user_data)
 {
     clocks.hh_adj = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(cb));
 }
 
-static void adj_mm_changed(GtkSpinButton *cb, gpointer user_data)
+static void adj_mm_changed (GtkSpinButton *cb, G_GNUC_UNUSED gpointer user_data)
 {
     clocks.mm_adj = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(cb));
 }
@@ -452,59 +527,60 @@ static void init_hdr_button(void)
     /* this shows also text, which we do not want:
     clocks.hdr_button = gtk_button_new_from_stock(GTK_STOCK_PREFERENCES);
     */
-    clocks.hdr_hbox = gtk_hbox_new(FALSE, 1);
-    gtk_box_pack_start(GTK_BOX(clocks.main_hbox)
-            , clocks.hdr_hbox, FALSE, FALSE, 0);
+    clocks.hdr_hbox = gtk_grid_new ();
+    gtk_grid_attach_next_to (GTK_GRID (clocks.main_hbox), clocks.hdr_hbox, NULL,
+                             GTK_POS_RIGHT, 1, 1);
     gtk_widget_show(clocks.hdr_hbox);
 
     clocks.hdr_button = gtk_button_new();
-    gtk_box_pack_start(GTK_BOX(clocks.hdr_hbox)
-            , clocks.hdr_button, FALSE, FALSE, 0);
-    gtk_tooltips_set_tip(clocks.tips, clocks.hdr_button
-            , _("button 1 to change preferences \nbutton 2 to adjust time of clocks"), NULL);
+    gtk_grid_attach_next_to (GTK_GRID (clocks.hdr_hbox), clocks.hdr_button,
+                             NULL, GTK_POS_RIGHT, 1, 1);
+    gtk_widget_set_tooltip_text(clocks.hdr_button
+            , _("button 1 to change preferences \nbutton 2 to adjust time of clocks"));
     g_signal_connect(clocks.hdr_button, "button_press_event"
             , G_CALLBACK(preferences_button_pressed), NULL);
-    image = gtk_image_new_from_stock(GTK_STOCK_PREFERENCES
-            , GTK_ICON_SIZE_BUTTON);
+    image = gtk_image_new_from_icon_name ("preferences-system",
+                                          GTK_ICON_SIZE_BUTTON);
     gtk_container_add(GTK_CONTAINER(clocks.hdr_button), GTK_WIDGET(image));
     gtk_widget_show(image);
     gtk_widget_show(clocks.hdr_button);
 
     clocks.hdr_adj_hh = gtk_spin_button_new_with_range(-24, 24, 1);
-    gtk_box_pack_start(GTK_BOX(clocks.hdr_hbox)
-            , clocks.hdr_adj_hh, FALSE, FALSE, 0);
+    gtk_grid_attach_next_to (GTK_GRID (clocks.hdr_hbox), clocks.hdr_adj_hh,
+                             NULL, GTK_POS_RIGHT, 1, 1);
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(clocks.hdr_adj_hh), (gdouble)0);
     gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(clocks.hdr_adj_hh), TRUE);
     gtk_widget_set_size_request(clocks.hdr_adj_hh, 45, -1);
-    gtk_tooltips_set_tip(clocks.tips, clocks.hdr_adj_hh
-            , _("adjust to change hour"), NULL);
+    gtk_widget_set_tooltip_text(clocks.hdr_adj_hh, _("adjust to change hour"));
     g_signal_connect((gpointer) clocks.hdr_adj_hh, "changed"
             , G_CALLBACK(adj_hh_changed), NULL);
 
     clocks.hdr_adj_sep = gtk_label_new(":");
-    gtk_box_pack_start(GTK_BOX(clocks.hdr_hbox)
-            , clocks.hdr_adj_sep, FALSE, FALSE, 0);
+    gtk_grid_attach_next_to (GTK_GRID (clocks.hdr_hbox), clocks.hdr_adj_sep,
+                             NULL, GTK_POS_RIGHT, 1, 1);
 
     clocks.hdr_adj_mm = gtk_spin_button_new_with_range(-60, 60, 1);
-    gtk_box_pack_start(GTK_BOX(clocks.hdr_hbox)
-            , clocks.hdr_adj_mm, FALSE, FALSE, 0);
+    gtk_grid_attach_next_to (GTK_GRID (clocks.hdr_hbox), clocks.hdr_adj_mm,
+                             NULL, GTK_POS_RIGHT, 1, 1);
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(clocks.hdr_adj_mm), (gdouble)0);
     gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(clocks.hdr_adj_mm), TRUE);
     gtk_spin_button_set_increments(GTK_SPIN_BUTTON(clocks.hdr_adj_mm), 30, 1);
     gtk_widget_set_size_request(clocks.hdr_adj_mm, 45, -1);
-    gtk_tooltips_set_tip(clocks.tips, clocks.hdr_adj_mm
-            , _("adjust to change minute. Click arrows with button 2 to change only 1 minute."), NULL);
+    gtk_widget_set_tooltip_text(clocks.hdr_adj_mm
+            , _("adjust to change minute. Click arrows with button 2 to change only 1 minute."));
     g_signal_connect((gpointer) clocks.hdr_adj_mm, "changed"
             , G_CALLBACK(adj_mm_changed), NULL);
     /* We want it to be hidden initially, it is special thing to do...
     gtk_widget_show(clocks.hdr_adj);
     */
-
 }
 
-static gboolean clean_up(GtkObject *obj, GdkEvent *event, gint g)
+static gboolean clean_up (G_GNUC_UNUSED GtkWidget *obj,
+                          G_GNUC_UNUSED GdkEvent *event,
+                          G_GNUC_UNUSED gpointer data)
 {
     write_file();
+
     return(FALSE);
 }
 
@@ -514,7 +590,7 @@ static void create_icon(void)
     GtkIconTheme *icon_theme;
 
     icon_theme = gtk_icon_theme_get_default();
-    clock_logo = gtk_icon_theme_load_icon(icon_theme, "orage_globaltime", 0
+    clock_logo = gtk_icon_theme_load_icon(icon_theme, "org.xfce.orage.globaltime", 0
             , GTK_ICON_LOOKUP_USE_BUILTIN, NULL);
     gtk_window_set_default_icon(clock_logo);
     gtk_window_set_icon(GTK_WINDOW(clocks.window), clock_logo);
@@ -524,9 +600,10 @@ static void create_icon(void)
 static void initialize_clocks(void)
 {
     GtkWidget *button;
+    gchar *font;
 
     clocks.clock_list = NULL;
-    strcpy(clocks.time_now, "88:88");
+    g_strlcpy (clocks.time_now, "88:88", sizeof (clocks.time_now));
     clocks.previous_secs = 61;      
     clocks.time_adj_act = FALSE;      
     clocks.no_update = FALSE;
@@ -541,27 +618,27 @@ static void initialize_clocks(void)
     */
     clocks.local_mday = 0;
     clocks.modified = 0;
-    clocks.tips = gtk_tooltips_new();
 
     /* Standard window-creating stuff */
     clocks.window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_title(GTK_WINDOW(clocks.window), NAME_VERSION);
+    gtk_window_set_title(GTK_WINDOW(clocks.window), _("Global Time"));
 
-    clocks.main_hbox = gtk_hbox_new(FALSE, 1);
-    gtk_container_add(GTK_CONTAINER(clocks.window)
-                    , clocks.main_hbox);
+    clocks.main_hbox = gtk_grid_new ();
+    gtk_container_add(GTK_CONTAINER(clocks.window), clocks.main_hbox);
     gtk_widget_show(clocks.main_hbox);
 
     init_hdr_button();
 
-    clocks.clocks_hbox = gtk_hbox_new(clocks.expand, 1);
-    gtk_box_pack_start(GTK_BOX(clocks.main_hbox)
-                    , clocks.clocks_hbox, FALSE, FALSE, 0);
+    clocks.clocks_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 1);
+    gtk_grid_attach_next_to (GTK_GRID (clocks.main_hbox), clocks.clocks_hbox,
+                             NULL, GTK_POS_RIGHT, 1, 1);
     gtk_widget_show(clocks.clocks_hbox);
 
-    clocks.clock_default_attr.clock_fg = g_new0(GdkColor,1);
+    clocks.clock_default_attr.clock_fg = g_new0 (GdkRGBA, 1);
+    gdk_rgba_parse (clocks.clock_default_attr.clock_fg, "black");
     clocks.clock_default_attr.clock_fg_modified = FALSE;
-    clocks.clock_default_attr.clock_bg = g_new0(GdkColor,1);
+    clocks.clock_default_attr.clock_bg = g_new0 (GdkRGBA, 1);
+    gdk_rgba_parse (clocks.clock_default_attr.clock_bg, "white");
     clocks.clock_default_attr.clock_fg_modified = FALSE;
     clocks.clock_default_attr.name_font = g_string_new("");
     clocks.clock_default_attr.name_font_modified = FALSE;
@@ -573,11 +650,12 @@ static void initialize_clocks(void)
     clocks.clock_default_attr.time_underline_modified = FALSE;
     /* find default font */
     button = gtk_font_button_new();
-    g_string_assign(clocks.clock_default_attr.name_font
-            , gtk_font_button_get_font_name((GtkFontButton *)button));
-    g_string_assign(clocks.clock_default_attr.time_font
-            , clocks.clock_default_attr.name_font->str);
-    gtk_object_sink(GTK_OBJECT(button));
+    font = gtk_font_chooser_get_font (GTK_FONT_CHOOSER (button));
+    g_string_assign (clocks.clock_default_attr.name_font, font);
+    g_string_assign (clocks.clock_default_attr.time_font,
+                     clocks.clock_default_attr.name_font->str);
+    g_free (font);
+    g_object_ref_sink(button);
 
     g_signal_connect(G_OBJECT(clocks.window), "delete-event"
             , G_CALLBACK(clean_up), NULL);
@@ -589,6 +667,7 @@ static void create_global_time(void)
 {
     gint pos = -1; /* to the end */
     GdkAtom atom;
+    GdkWindow *window;
 
     /* first check if we are active already */
     if (global_time_active_already(&atom))
@@ -598,8 +677,9 @@ static void create_global_time(void)
     clocks.hidden = gtk_invisible_new();
     gtk_widget_show(clocks.hidden);
 
-    if (!gdk_selection_owner_set(clocks.hidden->window, atom,
-            gdk_x11_get_server_time(clocks.hidden->window), FALSE)) {
+    window = gtk_widget_get_window (clocks.hidden);
+    if (!gdk_selection_owner_set(window, atom,
+            gdk_x11_get_server_time(window), FALSE)) {
         g_warning("Unable acquire ownership of selection");
     }
 
@@ -610,10 +690,10 @@ static void create_global_time(void)
     if (g_list_length(clocks.clock_list) == 0)
         add_default_clock();
 
-    /*
+#if 0
     get_time("GMT");
-    */
-    g_timeout_add(500, (GtkFunction)upd_clocks, NULL);
+#endif
+    g_timeout_add(500, (GSourceFunc)upd_clocks, NULL);
 
     g_list_foreach(clocks.clock_list, (GFunc) show_clock, &pos);
 
@@ -621,18 +701,13 @@ static void create_global_time(void)
     gtk_window_set_decorated(GTK_WINDOW(clocks.window), clocks.decorations);
     gtk_widget_show(clocks.window);
 
-    g_signal_connect(clocks.hidden, "client-event"
-            , G_CALLBACK(client_message_received), NULL);
+    gdk_window_add_filter (window, client_message_filter, NULL);
 }
 
 int main(int argc, char *argv[])
 {
     /* init i18n = nls to use gettext */
-    bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
-#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
-    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
-#endif
-    textdomain(GETTEXT_PACKAGE);
+    xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
     gtk_init(&argc, &argv);
     create_global_time();
