@@ -44,9 +44,12 @@
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 
+#include <libxfce4util/libxfce4util.h>
+
 #define ORAGE_MAIN  "orage"
 
 #include "orage-i18n.h"
+#include "orage-css.h"
 #include "functions.h"
 #include "mainbox.h"
 #include "reminder.h"
@@ -55,10 +58,13 @@
 #include "parameters.h"
 #include "interface.h"
 #ifdef HAVE_DBUS
-#include "orage-dbus.h"
+#include "orage-dbus-client.h"
 #include <dbus/dbus-glib-lowlevel.h>
 #endif
 
+#define CALENDAR_RAISE_EVENT "_XFCE_CALENDAR_RAISE"
+#define CALENDAR_PREFERENCES_EVENT "_XFCE_CALENDAR_PREFERENCES"
+
 /* session client handler */
 /*
 static SessionClient	*session_client = NULL;
@@ -66,20 +72,22 @@ static SessionClient	*session_client = NULL;
 static GdkAtom atom_alive;
 
 #ifdef HAVE_DBUS
-static gboolean resume_after_sleep(gpointer user_data)
+static gboolean resume_after_sleep (G_GNUC_UNUSED gpointer user_data)
 {
-    orage_message(10, "Resuming after sleep");
+    g_message ("Resuming after sleep");
     alarm_read();
     orage_day_change(&g_par);
+
     return(FALSE); /* only once */
 }
 
-static void resuming_cb(DBusGProxy *proxy, gpointer user_data)
+static void resuming_cb (G_GNUC_UNUSED DBusGProxy *proxy,
+                         G_GNUC_UNUSED gpointer user_data)
 {
-    orage_message(10, "Resuming");
+    g_message ("Resuming");
     /* we need this delay to prevent updating tray icon too quickly when
        the normal code handles it also */
-    g_timeout_add_seconds(2, (GtkFunction) resume_after_sleep, NULL);
+    g_timeout_add_seconds(2, (GSourceFunc) resume_after_sleep, NULL);
 }
 
 static void handle_resuming(void)
@@ -88,7 +96,6 @@ static void handle_resuming(void)
     GError *error = NULL;
     DBusGProxy *proxy;
 
-    g_type_init();
     connection = dbus_g_bus_get(DBUS_BUS_SYSTEM, &error);
     if (connection) {
        proxy = dbus_g_proxy_new_for_name(connection, "org.freedesktop.UPower"
@@ -99,74 +106,49 @@ static void handle_resuming(void)
                    , G_CALLBACK(resuming_cb), NULL, NULL);
        } 
        else {
-           g_warning("Failed to create proxy object\n");
+           g_warning("Failed to create proxy object");
        }
     } 
     else {
-        g_warning("Failed to connect to D-BUS daemon: %s\n", error->message);
+        g_warning("Failed to connect to D-BUS daemon: %s", error->message);
     }
 }
 #endif
 
-
-/* This function monitors that we do not loose time.  It checks if longer time
-   than expected wakeup time has passed and fixes timings if that is the case.
-   This is needed since sometimes hibernate and suspend does not do a good job
-   in firing Orage timers and timing gets wrong. 
-NOTE: called from parameters.c set_wakeup_timer
-*/
-gboolean check_wakeup(gpointer user_data)
+static void send_event (const char *event)
 {
-    static time_t tt_prev=0;
-    time_t tt_new=0;
-
-    tt_new = time(NULL);
-    if (tt_new - tt_prev > ORAGE_WAKEUP_TIMER_PERIOD * 2) {
-        /* we very rarely come here. */ 
-        /* user_data is normally NULL, but first call it has some value, 
-           which means that this is init call */
-        if (!user_data) { /* normal timer call */
-            orage_message(10, "wakeup timer refreshing");
-            alarm_read();
-            /* It is quite possible that day did not change, 
-               but we need to reset timers */
-            orage_day_change(&tt_prev); 
-        }
-        else {
-            orage_message(10, "wakeup timer init %d", tt_prev);
-        }
-    }
-    tt_prev = tt_new;
-    return(TRUE);
-}
-
-static void send_event(char *event)
-{
-    GdkEventClient gev;
+    XEvent xevent;
     Window xwindow;
+    Display *display;
 
-    memset(&gev, 0, sizeof(gev));
+    (void)memset (&xevent, 0, sizeof (xevent));
 
-    xwindow = XGetSelectionOwner(GDK_DISPLAY()
-            , gdk_x11_atom_to_xatom(atom_alive));
+    display = gdk_x11_get_default_xdisplay ();
+    xwindow = XGetSelectionOwner (display, gdk_x11_atom_to_xatom (atom_alive));
 
-    gev.type = GDK_CLIENT_EVENT;
-    gev.window = NULL;
-    gev.send_event = TRUE;
-    gev.message_type = gdk_atom_intern(event, FALSE);
-    gev.data_format = 8;
+    xevent.xclient.type = ClientMessage;
+    xevent.xclient.display = display;
+    xevent.xclient.window = xwindow;
+    xevent.xclient.send_event = TRUE;
+    xevent.xclient.message_type = XInternAtom (display, event, FALSE);
+    xevent.xclient.format = 8;
 
-    gdk_event_send_client_message((GdkEvent *)&gev, (GdkNativeWindow)xwindow);
+    if (XSendEvent (display, xwindow, FALSE, NoEventMask, &xevent) == 0)
+        g_warning ("send message to %s failed", event);
+
+    (void)XFlush (display);
 }
 
 void orage_toggle_visible(void)
 {
-    send_event("_XFCE_CALENDAR_TOGGLE_HERE");
+    g_debug ("%s: send '" CALENDAR_TOGGLE_EVENT "' event", G_STRFUNC);
+    send_event (CALENDAR_TOGGLE_EVENT);
 }
 
 static void raise_orage(void)
 {
-    send_event("_XFCE_CALENDAR_RAISE");
+    g_debug ("%s: send '" CALENDAR_RAISE_EVENT "' event", G_STRFUNC);
+    send_event (CALENDAR_RAISE_EVENT);
 }
 
 static gboolean keep_tidy(void)
@@ -181,8 +163,9 @@ static gboolean keep_tidy(void)
     return(TRUE);
 }
 
-static gboolean mWindow_delete_event_cb(GtkWidget *widget, GdkEvent *event
-        , gpointer user_data)
+static gboolean mWindow_delete_event_cb (G_GNUC_UNUSED GtkWidget *widget,
+                                         G_GNUC_UNUSED GdkEvent *event,
+                                         G_GNUC_UNUSED gpointer user_data)
 {
     if (g_par.close_means_quit) {
         gtk_main_quit();
@@ -190,6 +173,7 @@ static gboolean mWindow_delete_event_cb(GtkWidget *widget, GdkEvent *event
     else {
         orage_toggle_visible();
     }
+
     return(TRUE);
 }
 
@@ -207,41 +191,55 @@ static void raise_window(void)
         gtk_window_stick(GTK_WINDOW(cal->mWindow));
     gtk_window_set_keep_above(GTK_WINDOW(cal->mWindow)
             , g_par.set_ontop);
-    window = GTK_WIDGET(cal->mWindow)->window;
+    window = gtk_widget_get_window (GTK_WIDGET(cal->mWindow));
     gdk_x11_window_set_user_time(window, gdk_x11_get_server_time(window));
     gtk_widget_show(cal->mWindow);
     gtk_window_present(GTK_WINDOW(cal->mWindow));
 }
 
-static gboolean client_message_received(GtkWidget *widget
-        , GdkEventClient *event, gpointer user_data)
+static GdkFilterReturn client_message_filter (GdkXEvent *gdkxevent,
+                                              G_GNUC_UNUSED GdkEvent *event,
+                                              G_GNUC_UNUSED gpointer data)
 {
+    XClientMessageEvent *evt;
+    XEvent *xevent = (XEvent *)gdkxevent;
     CalWin *cal = (CalWin *)g_par.xfcal;
 
-    if (event->message_type ==
-            gdk_atom_intern("_XFCE_CALENDAR_RAISE", FALSE)) {
-        raise_window();
-        return(TRUE);
+    if (xevent->type != ClientMessage)
+        return GDK_FILTER_CONTINUE;
+
+    evt = (XClientMessageEvent *)gdkxevent;
+
+    if (evt->message_type ==
+            XInternAtom (evt->display, CALENDAR_RAISE_EVENT, FALSE))
+    {
+        g_debug ("received '" CALENDAR_RAISE_EVENT "' event");
+        raise_window ();
+        return GDK_FILTER_REMOVE;
     }
-    else if (event->message_type ==
-            gdk_atom_intern("_XFCE_CALENDAR_TOGGLE_HERE", FALSE)) {
-        if (GTK_WIDGET_VISIBLE(cal->mWindow)) {
-            write_parameters();
-            gtk_widget_hide(cal->mWindow);
-            return(TRUE);
-        }
-        else {
-            raise_window();
-            return(TRUE);
+    else if (evt->message_type ==
+             XInternAtom (evt->display, CALENDAR_TOGGLE_EVENT, FALSE))
+    {
+        g_debug ("received '" CALENDAR_TOGGLE_EVENT "' event");
+        if (gtk_widget_get_visible (cal->mWindow))
+        {
+            write_parameters ();
+            gtk_widget_hide (cal->mWindow);
         }
+        else
+            raise_window ();
+
+        return GDK_FILTER_REMOVE;
     }
-    else if (event->message_type ==
-            gdk_atom_intern("_XFCE_CALENDAR_PREFERENCES", FALSE)) {
-        show_parameters();
-        return(TRUE);
+    else if (evt->message_type ==
+            XInternAtom (evt->display, CALENDAR_PREFERENCES_EVENT, FALSE))
+    {
+        g_debug ("received '" CALENDAR_PREFERENCES_EVENT "' event");
+        show_parameters ();
+        return GDK_FILTER_REMOVE;
     }
 
-    return(FALSE);
+    return GDK_FILTER_CONTINUE;
 }
 
 /*
@@ -298,34 +296,39 @@ static void print_version(void)
     g_print(_("\tUsing operating system package libical.\n"));
 #else
     g_print(_("\tUsing Orage local version of libical.\n"));
+#endif
+#ifdef HAVE_LIBXFCE4UI
+    g_print(_("\tUsing libxfce4ui: yes\n"));
+#else
+    g_print(_("\tUsing libxfce4ui: no\n"));
 #endif
     g_print("\n");
 }
 
 static void preferences(void)
 {
-    send_event("_XFCE_CALENDAR_RAISE");
-    send_event("_XFCE_CALENDAR_PREFERENCES");
+    send_event (CALENDAR_RAISE_EVENT);
+    send_event (CALENDAR_PREFERENCES_EVENT);
 }
 
-static void print_help(void)
+static void print_help(void (*print_func) (const gchar *, ...))
 {
-    g_print(_("Usage: orage [options] [files]\n\n"));
-    g_print(_("Options:\n"));
-    g_print(_("--version (-v) \t\tshow version of orage\n"));
-    g_print(_("--help (-h) \t\tprint this text\n"));
-    g_print(_("--preferences (-p) \tshow preferences form\n"));
-    g_print(_("--toggle (-t) \t\tmake orage visible/unvisible\n"));
-    g_print(_("--add-foreign (-a) file [RW] [name] \tadd a foreign file\n"));
-    g_print(_("--remove-foreign (-r) file \tremove a foreign file\n"));
-    g_print(_("--export (-e) file [appointment...] \texport appointments from Orage to file\n"));
-    g_print("\n");
-    g_print(_("files=ical files to load into orage\n"));
+    print_func(_("Usage: orage [options] [files]\n\n"));
+    print_func(_("Options:\n"));
+    print_func(_("--version (-v) \t\tshow version of orage\n"));
+    print_func(_("--help (-h) \t\tprint this text\n"));
+    print_func(_("--preferences (-p) \tshow preferences form\n"));
+    print_func(_("--toggle (-t) \t\tmake orage visible/unvisible\n"));
+    print_func(_("--add-foreign (-a) file [RW] [name] \tadd a foreign file\n"));
+    print_func(_("--remove-foreign (-r) file \tremove a foreign file\n"));
+    print_func(_("--export (-e) file [appointment...] \texport appointments from Orage to file\n"));
+    print_func("\n");
+    print_func(_("files=ical files to load into orage\n"));
 #ifndef HAVE_DBUS
-    g_print(_("\tdbus not included in orage. \n"));
-    g_print(_("\twithout dbus [files] and foreign file options(-a & -r) can only be used when starting orage \n"));
+    print_func(_("\tdbus not included in orage. \n"));
+    print_func(_("\twithout dbus [files] and foreign file options(-a & -r) can only be used when starting orage \n"));
 #endif
-    g_print("\n");
+    print_func("\n");
 }
 
 static void import_file(gboolean running, char *file_name, gboolean initialized)
@@ -334,18 +337,19 @@ static void import_file(gboolean running, char *file_name, gboolean initialized)
         /* let's use dbus since server is running there already */
 #ifdef HAVE_DBUS
         if (orage_dbus_import_file(file_name))
-            orage_message(40, "import done file=%s", file_name);
+            g_message ("import done file=%s", file_name);
         else
-            g_warning("import failed file=%s\n", file_name);
+            g_warning ("import failed file=%s", file_name);
 #else
-        g_warning("Can not do import without dbus. import failed file=%s\n", file_name);
+        g_warning("Can not do import without dbus. import failed file=%s",
+                  file_name);
 #endif
     }
     else if (!running && initialized) {/* do it self directly */
         if (xfical_import_file(file_name))
-            orage_message(40, "import done file=%s", file_name);
+            g_message ("import done file=%s", file_name);
         else
-            g_warning("import failed file=%s\n", file_name);
+            g_warning ("import failed file=%s", file_name);
     }
 }
 
@@ -358,46 +362,48 @@ static void export_file(gboolean running, char *file_name, gboolean initialized
         type = 1;
     else
         type = 0;
-    g_print("export_file: running=%d initialized= %d type=%d, file=%s, uids=%s\n", running, initialized, type, file_name, uid_list);
+    g_message ("export_file: running=%d initialized= %d type=%d, file=%s, uids=%s\n",
+               running, initialized, type, file_name, uid_list);
     if (running && !initialized) {
         /* let's use dbus since server is running there already */
 #ifdef HAVE_DBUS
         if (orage_dbus_export_file(file_name, type, uid_list))
-            orage_message(40, "export done to file=%s", file_name);
+            g_message ("export done to file=%s", file_name);
         else
-            g_warning("export failed file=%s\n", file_name);
+            g_warning ("export failed file=%s", file_name);
 #else
-        g_warning("Can not do export without dbus. failed file=%s\n", file_name);
+        g_warning("Can not do export without dbus. failed file=%s", file_name);
 #endif
     }
     else if (!running && initialized) { /* do it self directly */
         if (xfical_export_file(file_name, type, uid_list))
-            orage_message(40, "export done to file=%s", file_name);
+            g_message ("export done to file=%s", file_name);
         else
-            g_warning("export failed file=%s\n", file_name);
+            g_warning ("export failed file=%s", file_name);
     }
 }
 
 static void add_foreign(gboolean running, char *file_name, gboolean initialized
         , gboolean read_only, char *name)
 {
-    g_print("\nadd_foreign: file_name%s name:%s\n\n", file_name, name);
+    g_message ("\nadd_foreign: file_name%s name:%s\n\n", file_name, name);
     if (running && !initialized) {
         /* let's use dbus since server is running there already */
 #ifdef HAVE_DBUS
         if (orage_dbus_foreign_add(file_name, read_only, name))
-            orage_message(40, "Add done online foreign file=%s", file_name);
+            g_message ("Add done online foreign file=%s", file_name);
         else
-            orage_message(140, "Add failed online foreign file=%s\n", file_name);
+            g_warning ("Add failed online foreign file=%s", file_name);
 #else
-        orage_message(140, "Can not do add foreign file to running Orage without dbus. Add failed foreign file=%s\n", file_name);
+        g_warning ("Can not do add foreign file to running Orage without dbus. "
+                   "Add failed foreign file=%s", file_name);
 #endif
     }
     else if (!running && initialized) { /* do it self directly */
         if (orage_foreign_file_add(file_name, read_only, name))
-            orage_message(40, "Add done foreign file=%s", file_name);
+            g_message ("Add done foreign file=%s", file_name);
         else
-            orage_message(140, "Add failed foreign file=%s\n", file_name);
+            g_warning ("Add failed foreign file=%s", file_name);
     }
 }
 
@@ -407,24 +413,25 @@ static void remove_foreign(gboolean running, char *file_name, gboolean initializ
         /* let's use dbus since server is running there already */
 #ifdef HAVE_DBUS
         if (orage_dbus_foreign_remove(file_name))
-            orage_message(40, "Remove done foreign file=%s", file_name);
+            g_message ("Remove done foreign file=%s", file_name);
         else
-            orage_message(140, "Remove failed foreign file=%s\n", file_name);
+            g_warning ("Remove failed foreign file=%s", file_name);
 #else
-        orage_message(140, "Can not do remove foreign file without dbus. Remove failed foreign file=%s\n", file_name);
+        g_warning ("Can not do remove foreign file without dbus. "
+                   "Remove failed foreign file=%s", file_name);
 #endif
     }
     else if (!running && initialized) { /* do it self directly */
         if (orage_foreign_file_remove(file_name))
-            orage_message(40, "Remove done foreign file=%s", file_name);
+            g_message ("Remove done foreign file=%s", file_name);
         else
-            orage_message(140, "Remove failed foreign file=%s\n", file_name);
+            g_warning ("Remove failed foreign file=%s", file_name);
     }
 }
 
 static gboolean process_args(int argc, char *argv[], gboolean running
         , gboolean initialized)
-{ 
+{
     int argi;
     gboolean end = FALSE;
     gboolean foreign_file_read_only = TRUE;
@@ -450,7 +457,7 @@ static gboolean process_args(int argc, char *argv[], gboolean running
         else if (!strcmp(argv[argi], "--help") || 
                  !strcmp(argv[argi], "-h")     ||
                  !strcmp(argv[argi], "-?")) {
-            print_help();
+            print_help(g_print);
             end = TRUE;
         }
         else if (!strcmp(argv[argi], "--preferences") || 
@@ -474,8 +481,8 @@ static gboolean process_args(int argc, char *argv[], gboolean running
         else if (!strcmp(argv[argi], "--add-foreign") ||
                  !strcmp(argv[argi], "-a")) {
             if (argi+1 >= argc) {
-                g_print("\nFile not specified\n\n");
-                print_help();
+                g_printerr("\nFile not specified\n\n");
+                print_help(g_printerr);
                 end = TRUE;
             } 
             else {
@@ -508,8 +515,8 @@ static gboolean process_args(int argc, char *argv[], gboolean running
         else if (!strcmp(argv[argi], "--remove-foreign") ||
                  !strcmp(argv[argi], "-r")) {
             if (argi+1 >= argc) {
-                g_print("\nFile not specified\n\n");
-                print_help();
+                g_printerr("\nFile not specified\n\n");
+                print_help(g_printerr);
                 end = TRUE;
             } 
             else {
@@ -519,8 +526,8 @@ static gboolean process_args(int argc, char *argv[], gboolean running
         else if (!strcmp(argv[argi], "--export") ||
                  !strcmp(argv[argi], "-e")) {
             if (argi+1 >= argc) {
-                g_print("\nFile not specified\n\n");
-                print_help();
+                g_printerr("\nFile not specified\n\n");
+                print_help(g_printerr);
                 end = TRUE;
             } 
             else {
@@ -532,8 +539,8 @@ static gboolean process_args(int argc, char *argv[], gboolean running
             }
         }
         else if (argv[argi][0] == '-') {
-            g_print(_("\nUnknown option %s\n\n"), argv[argi]);
-            print_help();
+            g_printerr(_("\nUnknown option %s\n\n"), argv[argi]);
+            print_help(g_printerr);
             end = TRUE;
         }
         else {
@@ -546,10 +553,8 @@ static gboolean process_args(int argc, char *argv[], gboolean running
 
 static gboolean check_orage_alive(void)
 {
-    Window xwindow;
-
-    if ((xwindow = XGetSelectionOwner(GDK_DISPLAY()
-            , gdk_x11_atom_to_xatom(atom_alive))) != None)
+    if (XGetSelectionOwner(gdk_x11_get_default_xdisplay(),
+                           gdk_x11_atom_to_xatom(atom_alive)) != None)
         return(TRUE); /* yes, we got selection owner, so orage must be there */
     else /* no selction owner, so orage is not running yet */
         return(FALSE);
@@ -558,15 +563,17 @@ static gboolean check_orage_alive(void)
 static void mark_orage_alive(void)
 {
     GtkWidget *hidden;
+    GdkWindow *window;
 
     hidden = gtk_invisible_new();
     gtk_widget_show(hidden);
-    if (!gdk_selection_owner_set(hidden->window, atom_alive
-                , gdk_x11_get_server_time(hidden->window), FALSE)) {
+    window = gtk_widget_get_window (hidden);
+    if (!gdk_selection_owner_set(window, atom_alive
+                , gdk_x11_get_server_time(window), FALSE)) {
         g_error("Unable acquire ownership of selection");
     }
-    g_signal_connect(hidden, "client-event"
-            , G_CALLBACK(client_message_received), NULL);
+
+    gdk_window_add_filter (window, client_message_filter, NULL);
 }
 
 int main(int argc, char *argv[])
@@ -574,15 +581,12 @@ int main(int argc, char *argv[])
     gboolean running, initialized = FALSE;
 
     /* init i18n = nls to use gettext */
-    bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
-#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
-    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
-#endif
-    textdomain(GETTEXT_PACKAGE);
+    xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
     gtk_init(&argc, &argv);
+    register_css_provider ();
 
-    atom_alive = gdk_atom_intern("_XFCE_CALENDAR_RUNNING", FALSE);
+    atom_alive = gdk_atom_intern (CALENDAR_RUNNING, FALSE);
     running = check_orage_alive();
     if (process_args(argc, argv, running, initialized)) 
         return(EXIT_SUCCESS);
@@ -637,7 +641,7 @@ int main(int argc, char *argv[])
             (GtkCalendar *)((CalWin *)g_par.xfcal)->mCalendar, NULL);
 
     /* start monitoring external file updates */
-    g_timeout_add_seconds(30, (GtkFunction)orage_external_update_check, NULL);
+    g_timeout_add_seconds(30, (GSourceFunc)orage_external_update_check, NULL);
 
     /* let's check if I got filename as a parameter */
     initialized = TRUE;
