@@ -24,6 +24,7 @@
 #include <config.h>
 #endif
 
+#include <glib.h>
 #include <glib-object.h>
 
 #include <dbus/dbus-glib-lowlevel.h>
@@ -55,7 +56,6 @@ OrageDBus *orage_dbus;
 
 static void orage_dbus_class_init(OrageDBusClass *orage_class)
 {
-    g_type_init();
     dbus_g_object_type_install_info(G_TYPE_FROM_CLASS(orage_class)
             , &dbus_glib_orage_object_info);
 }
@@ -73,14 +73,9 @@ static void orage_dbus_init(OrageDBus *o_dbus)
         g_error_free(error);
     }
     else {
-      /* register the /org/xfce/calendar object for orage */
+      /* register the /org/xfce/orage object for orage */
         dbus_g_connection_register_g_object(o_dbus->connection
-              , "/org/xfce/calendar", G_OBJECT(o_dbus));
-
-      /* request the org.xfce.calendar name for orage */
-        dbus_bus_request_name(dbus_g_connection_get_connection(
-                  o_dbus->connection), "org.xfce.calendar"
-              , DBUS_NAME_FLAG_REPLACE_EXISTING, NULL);
+              , "/org/xfce/orage", G_OBJECT(o_dbus));
 
       /* request the org.xfce.orage name for orage */
         dbus_bus_request_name(dbus_g_connection_get_connection(
@@ -89,12 +84,12 @@ static void orage_dbus_init(OrageDBus *o_dbus)
     }
 }
 
-gboolean orage_dbus_service_load_file(DBusGProxy *proxy
+gboolean orage_dbus_service_load_file (G_GNUC_UNUSED DBusGProxy *proxy
         , const char *IN_file
         , GError **error)
 {
     if (orage_import_file((char *)IN_file)) {
-        g_message("Orage **: DBUS File added %s", IN_file);
+        g_message ("DBUS File added %s", IN_file);
         return(TRUE);
     }
     else {
@@ -105,12 +100,12 @@ gboolean orage_dbus_service_load_file(DBusGProxy *proxy
     }
 }
 
-gboolean orage_dbus_service_export_file(DBusGProxy *proxy
+gboolean orage_dbus_service_export_file (G_GNUC_UNUSED DBusGProxy *proxy
         , const char *IN_file, const int IN_type, const char *IN_uids
-        , GError **error)
+        , G_GNUC_UNUSED GError **error)
 {
     if (orage_export_file((char *)IN_file, (gint)IN_type, (char *)IN_uids)) {
-        g_message("Orage **: DBUS File exported %s", IN_file);
+        g_message ("DBUS File exported %s", IN_file);
         return(TRUE);
     }
     else {
@@ -119,13 +114,13 @@ gboolean orage_dbus_service_export_file(DBusGProxy *proxy
     }
 }
 
-gboolean orage_dbus_service_add_foreign(DBusGProxy *proxy
+gboolean orage_dbus_service_add_foreign (G_GNUC_UNUSED DBusGProxy *proxy
         , const char *IN_file, const gboolean IN_mode, const char *IN_name
-        , GError **error)
+        , G_GNUC_UNUSED GError **error)
 {
     if (orage_foreign_file_add((char *)IN_file, (gboolean)IN_mode
                 , (char *)IN_name)) {
-        g_message("Orage **: DBUS Foreign file added %s", IN_file);
+        g_message ("DBUS Foreign file added %s", IN_file);
         return(TRUE);
     }
     else {
@@ -134,21 +129,20 @@ gboolean orage_dbus_service_add_foreign(DBusGProxy *proxy
     }
 }
 
-gboolean orage_dbus_service_remove_foreign(DBusGProxy *proxy
+gboolean orage_dbus_service_remove_foreign (G_GNUC_UNUSED DBusGProxy *proxy
         , const char *IN_file
-        , GError **error)
+        , G_GNUC_UNUSED GError **error)
 {
     if (orage_foreign_file_remove((char *)IN_file)) {
-        g_message("Orage **: DBUS Foreign file removed %s", IN_file);
+        g_message ("DBUS Foreign file removed %s", IN_file);
         return(TRUE);
     }
     else {
-        g_warning("Orage **: DBUS Foreign file remove failed %s", IN_file);
+        g_warning ("DBUS Foreign file remove failed %s", IN_file);
         return(FALSE);
     }
 }
 
-
 void orage_dbus_start(void)
 {
     orage_dbus = g_object_new(ORAGE_DBUS_TYPE, NULL);
