@@ -56,10 +56,6 @@
 #include "tray_icon.h"
 #include "parameters.h"
 
-/*
-#define ORAGE_DEBUG 1
-*/
-
 /* Compatibility macro for < libnotify-0.7 */
 /* NOTIFY_CHECK_VERSION was created in 0.5.2 */
 #ifndef NOTIFY_CHECK_VERSION
@@ -80,13 +76,8 @@ static void reset_orage_alarm_clock();
 
 static void alarm_free(gpointer galarm)
 {
-#undef P_N
-#define P_N "alarm_free: "
     alarm_struct *l_alarm = (alarm_struct *)galarm;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     g_free(l_alarm->alarm_time);
     g_free(l_alarm->action_time);
     g_free(l_alarm->uid);
@@ -102,12 +93,6 @@ static void alarm_free(gpointer galarm)
 
 static gint alarm_order(gconstpointer a, gconstpointer b)
 {
-#undef P_N
-#define P_N "alarm_order: "
-
-#ifdef ORAGE_DEBUG
-    orage_message(-300, P_N);
-#endif
     if (((alarm_struct *)a)->alarm_time == NULL)
         return(1);
     else if (((alarm_struct *)b)->alarm_time == NULL)
@@ -119,15 +104,10 @@ static gint alarm_order(gconstpointer a, gconstpointer b)
 
 void alarm_list_free(void)
 {
-#undef P_N
-#define P_N "alarm_free_all: "
     gchar *time_now;
     alarm_struct *l_alarm;
     GList *alarm_l, *kept_l=NULL;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     time_now = orage_tm_time_to_icaltime(orage_localtime());
         /* FIXME: This could be tuned since now it runs into the remaining
            elements several times. They could be moved to another list and
@@ -148,8 +128,8 @@ void alarm_list_free(void)
             kept_l = g_list_concat(kept_l, alarm_l);
         }
         else { /* get rid of that l_alarm element */
-            alarm_free(alarm_l->data);
             g_par.alarm_list=g_list_remove(g_par.alarm_list, l_alarm);
+            alarm_free(l_alarm);
         }
     }
     g_list_free(g_par.alarm_list);
@@ -162,12 +142,6 @@ void alarm_list_free(void)
 
 static void alarm_free_memory(alarm_struct *l_alarm)
 {
-#undef P_N
-#define P_N "alarm_free_memory: "
-
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     if (!l_alarm->display_orage && !l_alarm->display_notify && !l_alarm->audio)
         /* all gone, need to clean memory */
         alarm_free(l_alarm);
@@ -179,24 +153,13 @@ static void alarm_free_memory(alarm_struct *l_alarm)
 
 void alarm_add(alarm_struct *l_alarm)
 {
-#undef P_N
-#define P_N "alarm_add: "
-
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     g_par.alarm_list = g_list_prepend(g_par.alarm_list, l_alarm);
 }
 
 static alarm_struct *alarm_copy(alarm_struct *l_alarm, gboolean init)
 {
-#undef P_N
-#define P_N "alarm_copy: "
     alarm_struct *n_alarm;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     n_alarm = g_new0(alarm_struct, 1);
 
     /* first l_alarm values which are not modified */
@@ -255,19 +218,16 @@ static alarm_struct *alarm_copy(alarm_struct *l_alarm, gboolean init)
 
 static OrageRc *orage_persistent_file_open(gboolean read_only)
 {
-#undef P_N
-#define P_N "orage_persistent_file_open: "
     gchar *fpath;
     OrageRc *orc;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     fpath = orage_data_file_location(ORAGE_PERSISTENT_ALARMS_DIR_FILE);
     if (!read_only)  /* we need to empty it before each write */
-        g_remove(fpath);
+        if (g_remove(fpath)) {
+            g_warning ("%s: g_remove failed.", G_STRFUNC);
+        }
     if ((orc = (OrageRc *)orage_rc_file_open(fpath, read_only)) == NULL) {
-        orage_message(150, P_N "persistent alarms file open failed.");
+        g_warning ("%s: persistent alarms file open failed.", G_STRFUNC);
     }
     g_free(fpath);
 
@@ -276,14 +236,8 @@ static OrageRc *orage_persistent_file_open(gboolean read_only)
 
 static alarm_struct *alarm_read_next_alarm(OrageRc *orc, gchar *time_now)
 {
-#undef P_N
-#define P_N "alarm_read_next_alarm: "
     alarm_struct *new_alarm;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
-
     new_alarm = g_new0(alarm_struct, 1);
 
     new_alarm->uid = orage_rc_get_group(orc);
@@ -325,27 +279,20 @@ static alarm_struct *alarm_read_next_alarm(OrageRc *orc, gchar *time_now)
 
 void alarm_read(void)
 {
-#undef P_N
-#define P_N "alarm_read: "
     alarm_struct *new_alarm;
     OrageRc *orc;
     gchar *time_now;
     gchar **alarm_groups;
     gint i;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
-
     time_now = orage_tm_time_to_icaltime(orage_localtime());
     orc = orage_persistent_file_open(TRUE);
     alarm_groups = orage_rc_get_groups(orc);
     for (i = 0; alarm_groups[i] != NULL; i++) {
         orage_rc_set_group(orc, alarm_groups[i]);
         if ((new_alarm = alarm_read_next_alarm(orc, time_now)) != NULL) {
-            /*
-            g_print(P_N "time_now=%s alarm=%s\n", time_now, new_alarm->alarm_time);
-            */
+            g_debug ("%s: time_now=%s alarm=%s",
+                     G_STRFUNC, time_now, new_alarm->alarm_time);
             create_reminders(new_alarm);
             alarm_free(new_alarm);
         }
@@ -356,14 +303,9 @@ void alarm_read(void)
 
 static void alarm_store(gpointer galarm, gpointer par)
 {
-#undef P_N
-#define P_N "alarm_store: "
     alarm_struct *l_alarm = (alarm_struct *)galarm;
     OrageRc *orc = (OrageRc *)par;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-200, P_N);
-#endif
     if (!l_alarm->persistent)
         return; /* only store persistent alarms */
 
@@ -391,13 +333,8 @@ static void alarm_store(gpointer galarm, gpointer par)
 
 static void store_persistent_alarms(void)
 {
-#undef P_N
-#define P_N "store_persistent_alarms: "
     OrageRc *orc;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     orc = orage_persistent_file_open(FALSE);
     g_list_foreach(g_par.alarm_list, alarm_store, (gpointer)orc);
     orage_rc_file_close(orc);
@@ -408,16 +345,11 @@ static void store_persistent_alarms(void)
 /************************************************************/
 
 #ifdef HAVE_NOTIFY
-static void notify_action_open(NotifyNotification *n, const char *action
-        , gpointer par)
+static void notify_action_open (G_GNUC_UNUSED NotifyNotification *n,
+                                G_GNUC_UNUSED const char *action, gpointer par)
 {
-#undef P_N
-#define P_N "notify_action_open: "
     alarm_struct *l_alarm = (alarm_struct *)par;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     /* 
      * These two lines would keep notify window active and make it possible
      * to start several times the appointment or start it and still be 
@@ -431,16 +363,11 @@ static void notify_action_open(NotifyNotification *n, const char *action
 
 static gboolean sound_alarm(gpointer data)
 {
-#undef P_N
-#define P_N "sound_alarm: "
     alarm_struct *l_alarm = (alarm_struct *)data;
     GError *error = NULL;
     gboolean status;
     GtkWidget *stop;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     /* note: -1 loops forever */
     if (l_alarm->repeat_cnt != 0) {
         if (l_alarm->active_alarm->sound_active) {
@@ -449,7 +376,8 @@ static gboolean sound_alarm(gpointer data)
         status = orage_exec(l_alarm->sound_cmd
                 , &l_alarm->active_alarm->sound_active, &error);
         if (!status) {
-            g_warning("reminder: play failed (%s) %s", l_alarm->sound, error->message);
+            g_warning ("%s: play failed (%s) %s", G_STRFUNC, l_alarm->sound,
+                       error->message);
             l_alarm->repeat_cnt = 0; /* one warning is enough */
             status = TRUE; /* we need to come back once to do cleanout */
         }
@@ -482,12 +410,6 @@ static gboolean sound_alarm(gpointer data)
 
 static void create_sound_reminder(alarm_struct *l_alarm)
 {
-#undef P_N
-#define P_N "create_sound_reminder: "
-
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     l_alarm->sound_cmd = g_strconcat(g_par.sound_application, " \""
         , l_alarm->sound, "\"", NULL);
     l_alarm->active_alarm->sound_active = FALSE;
@@ -495,23 +417,15 @@ static void create_sound_reminder(alarm_struct *l_alarm)
         l_alarm->repeat_cnt++; /* need to do it once */
     }
 
-    g_timeout_add_seconds(l_alarm->repeat_delay, (GtkFunction) sound_alarm
+    g_timeout_add_seconds(l_alarm->repeat_delay, (GSourceFunc) sound_alarm
             , (gpointer) l_alarm);
 }
 
 #ifdef HAVE_NOTIFY
-static void notify_closed(NotifyNotification *n, gpointer par)
+static void notify_closed (G_GNUC_UNUSED NotifyNotification *n, gpointer par)
 {
-#undef P_N
-#define P_N "notify_closed: "
     alarm_struct *l_alarm = (alarm_struct *)par;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
-    /*
-    g_print("notify_closed: start %d %d\n",  l_alarm->audio, l_alarm->display_notify);
-    */
     if (l_alarm->notify_refresh) {
         /* this is not really closing notify, but only a refresh, so
          * we do not clean the memory now */
@@ -523,16 +437,12 @@ static void notify_closed(NotifyNotification *n, gpointer par)
     }
 }
 
-static void notify_action_silence(NotifyNotification *n, const char *action
+static void notify_action_silence (G_GNUC_UNUSED NotifyNotification *n,
+                                   G_GNUC_UNUSED const char *action
         , gpointer par)
 {
-#undef P_N
-#define P_N "notify_action_silence: "
     alarm_struct *l_alarm = (alarm_struct *)par;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     /* notify system will raise notify_closed also, so we need to mark that
        this is not a real close, but just a refresh, so that memory is not 
        freed */
@@ -544,22 +454,16 @@ static void notify_action_silence(NotifyNotification *n, const char *action
 
 static void create_notify_reminder(alarm_struct *l_alarm) 
 {
-#undef P_N
-#define P_N "create_notify_reminder: "
-
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
 #ifdef HAVE_NOTIFY
     char heading[250];
     NotifyNotification *n;
 
     if (!notify_init("Orage")) {
-        orage_message(150, "Notify init failed\n");
+        g_warning ("Notify init failed");
         return;
     }
 
-    strncpy(heading,  _("Reminder "), 100);
+    g_strlcpy(heading,  _("Reminder "), sizeof (heading));
     if (l_alarm->title)
         g_strlcat(heading, l_alarm->title, 150);
     if (l_alarm->action_time) {
@@ -574,7 +478,7 @@ static void create_notify_reminder(alarm_struct *l_alarm)
 #else
     n = notify_notification_new(heading, l_alarm->description, NULL, NULL);
     if (g_par.trayIcon 
-    && gtk_status_icon_is_embedded((GtkStatusIcon *)g_par.trayIcon))
+    && orage_status_icon_is_embedded ((GtkStatusIcon *)g_par.trayIcon))
         notify_notification_attach_to_status_icon(n
                 , (GtkStatusIcon *)g_par.trayIcon);
 #endif
@@ -603,22 +507,19 @@ static void create_notify_reminder(alarm_struct *l_alarm)
            , G_CALLBACK(notify_closed), l_alarm);
 
     if (!notify_notification_show(n, NULL)) {
-        orage_message(150, "failed to send notification");
+        g_warning ("failed to send notification");
     }
 #else
-    orage_message(150, "libnotify not linked in. Can't use notifications.");
+    g_warning ("libnotify not linked in. Can't use notifications.");
+    (void)l_alarm;
 #endif
 }
 
-static void destroy_orage_reminder(GtkWidget *wReminder, gpointer user_data)
+static void destroy_orage_reminder (G_GNUC_UNUSED GtkWidget *wReminder,
+                                    gpointer user_data)
 {
-#undef P_N
-#define P_N "destroy_orage_reminder: "
     alarm_struct *l_alarm = (alarm_struct *)user_data;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     l_alarm->display_orage = FALSE; /* I am gone */
     alarm_free_memory(l_alarm);
 }
@@ -626,53 +527,36 @@ static void destroy_orage_reminder(GtkWidget *wReminder, gpointer user_data)
 static void on_btStopNoiseReminder_clicked(GtkButton *button
         , gpointer user_data)
 {
-#undef P_N
-#define P_N "on_btStopNoiseReminder_clicked: "
     alarm_struct *l_alarm = (alarm_struct *)user_data;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     l_alarm->repeat_cnt = 0;
     gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
 }
 
-static void on_btOkReminder_clicked(GtkButton *button, gpointer user_data)
+static void on_btOkReminder_clicked (G_GNUC_UNUSED GtkButton *button,
+                                     gpointer user_data)
 {
-#undef P_N
-#define P_N "on_btOkReminder_clicked: "
     GtkWidget *wReminder = (GtkWidget *)user_data;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     gtk_widget_destroy(wReminder); /* destroy the specific appointment window */
 }
 
-static void on_btOpenReminder_clicked(GtkButton *button, gpointer user_data)
+static void on_btOpenReminder_clicked (G_GNUC_UNUSED GtkButton *button,
+                                       gpointer user_data)
 {
-#undef P_N
-#define P_N "on_btOpenReminder_clicked: "
     alarm_struct *l_alarm = (alarm_struct *)user_data;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     create_appt_win("UPDATE", l_alarm->uid);
 }
 
-static void on_btRecreateReminder_clicked(GtkButton *button, gpointer user_data)
+static void on_btRecreateReminder_clicked (G_GNUC_UNUSED GtkButton *button,
+                                           gpointer user_data)
 {
-#undef P_N
-#define P_N "on_btRecreateReminder_clicked: "
     alarm_struct *l_alarm = (alarm_struct *)user_data;
     orage_ddmmhh_hbox_struct *display_data;
     alarm_struct *n_alarm;
     time_t tt;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     display_data = (orage_ddmmhh_hbox_struct *)l_alarm->orage_display_data;
     /* we do not have l_alarm time here */
     n_alarm = alarm_copy(l_alarm, FALSE);
@@ -694,8 +578,6 @@ static void on_btRecreateReminder_clicked(GtkButton *button, gpointer user_data)
 
 static void create_orage_reminder(alarm_struct *l_alarm)
 {
-#undef P_N
-#define P_N "create_orage_reminder: "
     GtkWidget *wReminder;
     GtkWidget *vbReminder;
     GtkWidget *lbReminder;
@@ -711,9 +593,6 @@ static void create_orage_reminder(alarm_struct *l_alarm)
     GtkWidget *e_hbox;
     gchar *tmp;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     wReminder = gtk_dialog_new();
     gtk_widget_set_size_request(wReminder, -1, 250);
     gtk_window_set_title(GTK_WINDOW(wReminder),  _("Reminder - Orage"));
@@ -723,7 +602,7 @@ static void create_orage_reminder(alarm_struct *l_alarm)
     gtk_window_set_keep_above(GTK_WINDOW(wReminder), TRUE);
 
     /* Main AREA */
-    vbReminder = GTK_DIALOG(wReminder)->vbox;
+    vbReminder = gtk_dialog_get_content_area (GTK_DIALOG(wReminder));
 
     hdReminder = gtk_label_new(NULL);
     gtk_label_set_selectable(GTK_LABEL(hdReminder), TRUE);
@@ -749,9 +628,9 @@ static void create_orage_reminder(alarm_struct *l_alarm)
     lbReminder = gtk_label_new(l_alarm->description);
     gtk_label_set_line_wrap(GTK_LABEL(lbReminder), TRUE);
     gtk_label_set_selectable(GTK_LABEL(lbReminder), TRUE);
-    gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(swReminder)
-            , lbReminder);
-    
+
+    gtk_container_add (GTK_CONTAINER (swReminder), lbReminder);
+
  /* TIME AREA */
     ddmmhh_hbox = (orage_ddmmhh_hbox_struct *)l_alarm->orage_display_data;
     ddmmhh_hbox->spin_dd = gtk_spin_button_new_with_range(0, 100, 1);
@@ -766,32 +645,40 @@ static void create_orage_reminder(alarm_struct *l_alarm)
             , ddmmhh_hbox->spin_hh, ddmmhh_hbox->spin_hh_label
             , ddmmhh_hbox->spin_mm, ddmmhh_hbox->spin_mm_label);
     /* we want it to the left: */
-    e_hbox = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_end(GTK_BOX(e_hbox), ddmmhh_hbox->time_hbox, FALSE, FALSE, 0);
+
+    e_hbox = gtk_grid_new ();
+    gtk_grid_attach_next_to (GTK_GRID (e_hbox), ddmmhh_hbox->time_hbox, NULL,
+                             GTK_POS_RIGHT, 1, 1);
     gtk_box_pack_end(GTK_BOX(vbReminder), e_hbox, FALSE, FALSE, 0);
     ddmmhh_hbox->dialog = wReminder;
 
- /* ACTION AREA */
-    daaReminder = GTK_DIALOG(wReminder)->action_area;
-    gtk_dialog_set_has_separator(GTK_DIALOG(wReminder), FALSE);
-    gtk_button_box_set_layout(GTK_BUTTON_BOX(daaReminder), GTK_BUTTONBOX_END);
+    /* ACTION AREA: Following two lines change buttons layout in dialog window.
+     * GTK4 does not have 'gtk_dialog_get_action_area' function. However,
+     * following two lines is safe to remove, then reminder box have GTK defaul
+     * buttons layout in reminder dialog.
+     */
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+    daaReminder = gtk_dialog_get_action_area (GTK_DIALOG (wReminder));
+    G_GNUC_END_IGNORE_DEPRECATIONS
+    gtk_button_box_set_layout(GTK_BUTTON_BOX(daaReminder), GTK_BUTTONBOX_EXPAND);
 
     if (l_alarm->uid) {
-        btOpenReminder = gtk_button_new_from_stock("gtk-open");
+        btOpenReminder = orage_util_image_button ("document-open", _("_Open"));
         gtk_dialog_add_action_widget(GTK_DIALOG(wReminder), btOpenReminder
                 , GTK_RESPONSE_OK);
         g_signal_connect((gpointer) btOpenReminder, "clicked"
                 , G_CALLBACK(on_btOpenReminder_clicked), l_alarm);
     }
 
-    btOkReminder = gtk_button_new_from_stock("gtk-close");
+    btOkReminder = orage_util_image_button ("window-close", _("_Close"));
     gtk_dialog_add_action_widget(GTK_DIALOG(wReminder), btOkReminder
             , GTK_RESPONSE_OK);
     g_signal_connect((gpointer) btOkReminder, "clicked"
             , G_CALLBACK(on_btOkReminder_clicked), wReminder);
 
     if ((l_alarm->audio) && (l_alarm->repeat_cnt > 1)) {
-        btStopNoiseReminder = gtk_button_new_from_stock("gtk-stop");
+        btStopNoiseReminder = orage_util_image_button ("process-stop",
+                                                       _("_Stop"));
         l_alarm->active_alarm->stop_noise_reminder = btStopNoiseReminder;
         gtk_dialog_add_action_widget(GTK_DIALOG(wReminder)
                 , btStopNoiseReminder, GTK_RESPONSE_OK);
@@ -799,8 +686,7 @@ static void create_orage_reminder(alarm_struct *l_alarm)
             G_CALLBACK(on_btStopNoiseReminder_clicked), l_alarm);
     }
 
-    btRecreateReminder = orage_create_custom_stock_button("gtk-ok"
-            , _("Postpone"));
+    btRecreateReminder = orage_util_image_button ("gtk-ok", _("Postpone"));
     gtk_widget_set_tooltip_text(btRecreateReminder
             , _("Remind me again after the specified time"));
     gtk_dialog_add_action_widget(GTK_DIALOG(wReminder)
@@ -815,21 +701,16 @@ static void create_orage_reminder(alarm_struct *l_alarm)
 
 static void create_procedure_reminder(alarm_struct *l_alarm)
 {
-#undef P_N
-#define P_N "create_procedure_reminder: "
-    /*
+#if 0
     gboolean status, active; / * active not used * /
     GError *error = NULL;
-    */
-    gchar *cmd, *tmp, *atime, *sep;
+#endif
+    gchar *cmd, *atime, *sep = NULL;
     gint status;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
-    /*
+#if 0
     status = orage_exec(l_alarm->cmd, &active, &error);
-    */
+#endif
     cmd = g_strconcat(l_alarm->cmd, " &", NULL);
 
     cmd = orage_replace_text(cmd, "<&T>", l_alarm->title);
@@ -846,15 +727,17 @@ static void create_procedure_reminder(alarm_struct *l_alarm)
     /* l_alarm->action_time format is <start-time - end-time>
     and times are in user format already. Problem is if that format contain
     string " - " already, but let's hope not.  */
-    sep = strstr(l_alarm->action_time, " - ");
+    if (l_alarm->action_time != NULL)
+        sep = strstr(l_alarm->action_time, " - ");
+
     if (sep) { /* we should always have this */
         if (strstr(sep+1, " - ")) {
             /* this is problem as now we have more than one separator.
                We could try to find the middle one using strlen, but as
                there probably is not this kind of issues, it is not worth
                the trouble */
-            orage_message(10, P_N "<&ST>/<&ET> string conversion failed (%s)"
-                    , l_alarm->action_time);
+            g_message ("%s: <&ST>/<&ET> string conversion failed (%s)",
+                       G_STRFUNC, l_alarm->action_time);
         }
         else {
             sep[0] = '\0'; /* temporarily to end start-time string */
@@ -866,24 +749,22 @@ static void create_procedure_reminder(alarm_struct *l_alarm)
         }
     }
     else 
-        orage_message(10, P_N "<&ST>/<&ET> string conversion failed 2 (%s)"
-                , l_alarm->action_time);
+        g_message ("%s: <&ST>/<&ET> string conversion failed 2 (%s)", G_STRFUNC,
+                   l_alarm->action_time);
 
     status = system(cmd);
     if (status)
-        g_warning(P_N "cmd failed(%s)->(%s) status:%d", l_alarm->cmd, cmd, status);
+    {
+        g_warning ("%s: cmd failed(%s)->(%s) status:%d",
+                   G_STRFUNC, l_alarm->cmd, cmd, status);
+    }
     g_free(cmd);
 }
 
 void create_reminders(alarm_struct *l_alarm)
 {
-#undef P_N
-#define P_N "create_reminders: "
     alarm_struct *n_alarm;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     /* FIXME: instead of copying this new private version of the l_alarm,
      * g_list_remove(GList *g_par.alarm_list, gconstpointer l_alarm);
      * remove it and use the original. saves time */
@@ -901,14 +782,9 @@ void create_reminders(alarm_struct *l_alarm)
 
 static void reset_orage_day_change(gboolean changed)
 {
-#undef P_N
-#define P_N "reset_orage_day_change: "
     struct tm *t;
     gint secs_left;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     if (changed) { /* date was change, need to count next change time */
         t = orage_localtime();
         /* t format is 23:59:59 -> 00:00:00 so we can use 
@@ -920,7 +796,7 @@ static void reset_orage_day_change(gboolean changed)
         secs_left = 1;
     }
     g_par.day_timer = g_timeout_add_seconds(secs_left
-            , (GtkFunction) orage_day_change, NULL);
+            , (GSourceFunc) orage_day_change, NULL);
 }
 
 /* fire after the date has changed and setup the icon 
@@ -928,16 +804,11 @@ static void reset_orage_day_change(gboolean changed)
  */
 gboolean orage_day_change(gpointer user_data)
 {
-#undef P_N
-#define P_N "orage_day_change: "
     struct tm *t;
     static gint previous_year=0, previous_month=0, previous_day=0;
     guint selected_year=0, selected_month=0, selected_day=0;
     gint current_year=0, current_month=0, current_day=0;
-                                                                                
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
+
     t = orage_localtime();
   /* See if the day just changed. 
      Note that when we are called first time we always have day change. 
@@ -984,19 +855,14 @@ gboolean orage_day_change(gpointer user_data)
 }
 
 /* check and raise alarms if there are any */
-static gboolean orage_alarm_clock(gpointer user_data)
+static gboolean orage_alarm_clock (G_GNUC_UNUSED gpointer user_data)
 {
-#undef P_N
-#define P_N "orage_alarm_clock: "
     GList *alarm_l;
     alarm_struct *cur_alarm;
     gboolean alarm_raised=FALSE;
     gboolean more_alarms=TRUE;
     gchar *time_now;
-                                                                                
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
+
     time_now = orage_tm_time_to_icaltime(orage_localtime());
   /* Check if there are any alarms to show */
     for (alarm_l = g_list_first(g_par.alarm_list);
@@ -1005,9 +871,8 @@ static gboolean orage_alarm_clock(gpointer user_data)
         /* remember that it is sorted list */
         cur_alarm = (alarm_struct *)alarm_l->data;
         if (strcmp(time_now, cur_alarm->alarm_time) > 0) {
-            /*
-            g_print(P_N "time_now=%s alarm=%s\n", time_now, cur_alarm->alarm_time);
-            */
+            g_debug ("%s: time_now=%s alarm=%s",
+                     G_STRFUNC, time_now, cur_alarm->alarm_time);
             create_reminders(cur_alarm);
             alarm_raised = TRUE;
         }
@@ -1018,13 +883,12 @@ static gboolean orage_alarm_clock(gpointer user_data)
         xfical_alarm_build_list(FALSE); /* this calls reset_orage_alarm_clock */
     else
         reset_orage_alarm_clock(); /* need to setup next timer */
+
     return(FALSE); /* only once */
 }
 
 static void reset_orage_alarm_clock(void)
 {
-#undef P_N
-#define P_N "reset_orage_alarm_clock: "
     struct tm *t, t_alarm, t2;
     GList *alarm_l;
     alarm_struct *cur_alarm;
@@ -1032,9 +896,6 @@ static void reset_orage_alarm_clock(void)
     gint secs_to_alarm;
     gint dd;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     if (g_par.alarm_timer) { /* need to stop it if running */
         g_source_remove(g_par.alarm_timer);
         g_par.alarm_timer = 0;
@@ -1058,15 +919,13 @@ static void reset_orage_alarm_clock(void)
         if (secs_to_alarm < 1) /* rare, but possible */
             secs_to_alarm = 1;
         g_par.alarm_timer = g_timeout_add_seconds(secs_to_alarm
-                , (GtkFunction) orage_alarm_clock, NULL);
+                , (GSourceFunc) orage_alarm_clock, NULL);
     }
 }
 
 /* refresh trayicon tooltip once per minute */
-static gboolean orage_tooltip_update(gpointer user_data)
+static gboolean orage_tooltip_update (G_GNUC_UNUSED gpointer user_data)
 {
-#undef P_N
-#define P_N "orage_tooltip_update: "
     struct tm *t;
     GList *alarm_l;
     alarm_struct *cur_alarm;
@@ -1079,11 +938,8 @@ static gboolean orage_tooltip_update(gpointer user_data)
     GDate *g_now, *g_alarm;
     gchar *tmp;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     if (!(g_par.trayIcon 
-    && gtk_status_icon_is_embedded((GtkStatusIcon *)g_par.trayIcon))) {
+    && orage_status_icon_is_embedded ((GtkStatusIcon *)g_par.trayIcon))) {
            /* no trayicon => no need to update the tooltip */
         return(FALSE);
     }
@@ -1124,9 +980,10 @@ static gboolean orage_tooltip_update(gpointer user_data)
                 hh += 24;
                 dd -= 1;
             }
-/*
-    orage_message(10, P_N "tooltip: alarm=%s hh=%d hh=%d min=%d", cur_alarm->alarm_time, dd, hh, min);
-*/
+
+            g_debug ("%s: tooltip, alarm=%s hh=%d hh=%d min=%d", G_STRFUNC,
+                     cur_alarm->alarm_time, dd, hh, min);
+
             g_string_append(tooltip, "<span weight=\"bold\">");
             tooltip_highlight_helper = g_string_new(" </span>");
             if (cur_alarm->temporary) { /* let's add a small mark */
@@ -1152,41 +1009,34 @@ static gboolean orage_tooltip_update(gpointer user_data)
     }
     if (alarm_cnt == 0)
         g_string_append_printf(tooltip, _("\nNo active alarms found"));
-    gtk_status_icon_set_tooltip_markup((GtkStatusIcon *)g_par.trayIcon, tooltip->str);
+
+    orage_status_icon_set_tooltip_markup ((GtkStatusIcon *)g_par.trayIcon, tooltip->str);
+
     g_string_free(tooltip, TRUE);
+
     return(TRUE);
 }
 
 /* start timer to fire every minute to keep tooltip accurate */
-static gboolean start_orage_tooltip_update(gpointer user_data)
+static gboolean start_orage_tooltip_update (G_GNUC_UNUSED gpointer user_data)
 {
-#undef P_N
-#define P_N "start_orage_tooltip_update: "
-
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     if (g_par.tooltip_timer) { /* need to stop it if running */
         g_source_remove(g_par.tooltip_timer);
     }
 
     orage_tooltip_update(NULL);
     g_par.tooltip_timer = g_timeout_add_seconds(60
-            , (GtkFunction) orage_tooltip_update, NULL);
+            , (GSourceFunc) orage_tooltip_update, NULL);
+
     return(FALSE);
 }
 
 /* adjust the call to happen when minute changes */
-static gboolean reset_orage_tooltip_update(void)
+static gboolean reset_orage_tooltip_update (G_GNUC_UNUSED gpointer user_data)
 {
-#undef P_N
-#define P_N "reset_orage_tooltip_update: "
     struct tm *t;
     gint secs_left;
 
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     t = orage_localtime();
     secs_left = 60 - t->tm_sec;
     if (secs_left > 2) 
@@ -1197,23 +1047,18 @@ static gboolean reset_orage_tooltip_update(void)
      * Perhaps not worth fixing. 
      * Should add another timer or static time to keep track of this */
     g_timeout_add_seconds(secs_left
-            , (GtkFunction) start_orage_tooltip_update, NULL);
+            , (GSourceFunc) start_orage_tooltip_update, NULL);
+
     return(FALSE);
 }
 
 void setup_orage_alarm_clock(void)
 {
-#undef P_N
-#define P_N "setup_orage_alarm_clock: "
-
-#ifdef ORAGE_DEBUG
-    orage_message(-100, P_N);
-#endif
     /* order the list */
     g_par.alarm_list = g_list_sort(g_par.alarm_list, alarm_order);
     reset_orage_alarm_clock();
     store_persistent_alarms(); /* keep track of alarms when orage is down */
     /* We need to use timer since for some reason it does not work if we
      * do it here directly. Ugly, I know, but it works. */
-    g_timeout_add_seconds(1, (GtkFunction) reset_orage_tooltip_update, NULL);
+    g_timeout_add_seconds(1, (GSourceFunc) reset_orage_tooltip_update, NULL);
 }
