@@ -22,6 +22,7 @@
 #include <errno.h>
     /* errno */
 
+#include <glib.h>
 #include <stdlib.h>
     /* malloc, atoi, free, setenv */
 
@@ -100,12 +101,12 @@ unsigned char *begin_timechangetypes;
 /* timezone name table */
 unsigned char *begin_timezonenames;         
 
-unsigned long gmtcnt;
-unsigned long stdcnt;
-unsigned long leapcnt;
-unsigned long timecnt;  /* points when time changes */
-unsigned long typecnt;  /* table of different time changes = types */
-unsigned long charcnt;  /* length of timezone name table */
+int gmtcnt;
+int stdcnt;
+int leapcnt;
+int timecnt;  /* points when time changes */
+int typecnt;  /* table of different time changes = types */
+int charcnt;  /* length of timezone name table */
 
 struct ical_timezone_data {
     struct tm start_time;
@@ -120,20 +121,26 @@ struct rdate_prev_data {
     struct rdate_prev_data   *next;
 };
 
-void read_file(const char *file_name, const struct stat *file_stat)
+static void read_file(const char *file_name, const struct stat *file_stat)
 {
     FILE *file;
+    const size_t file_size = file_stat->st_size;
 
     if (debug > 1) {
         printf("read_file: start\n");
-        printf("\n***** size of file %s is %d bytes *****\n\n", file_name
-                , (int)file_stat->st_size);
+        printf("\n***** size of file %s is %zu bytes *****\n\n", file_name
+                , file_size);
     }
-    in_buf = malloc(file_stat->st_size);
+    in_buf = g_malloc0 (file_size);
     in_head = in_buf;
-    in_tail = in_buf + file_stat->st_size - 1;
+    in_tail = in_buf + file_size - 1;
     file = fopen(file_name, "r");
-    if (!fread(in_buf, 1, file_stat->st_size, file))
+    if (!file) {
+        printf("read_file: file open failed (%s)\n", file_name);
+        perror("\tfopen");
+        return;
+    }
+    if (fread(in_buf, 1, file_size, file) < file_size)
         if (ferror(file)) {
             printf("read_file: file read failed (%s)\n", file_name);
             fclose(file);
@@ -145,7 +152,7 @@ void read_file(const char *file_name, const struct stat *file_stat)
         printf("read_file: end\n");
 }
 
-int get_long()
+static int get_long(void)
 {
     int tmp;
 
@@ -157,7 +164,7 @@ int get_long()
     return(tmp);
 }
 
-int process_header()
+static int process_header(void)
 {
     if (debug > 2)
         printf("file id: %s\n", in_head);
@@ -169,27 +176,27 @@ int process_header()
     in_head += 16; /* reserved */
     gmtcnt  = get_long();
     if (debug > 2)
-        printf("gmtcnt=%lu \n", gmtcnt);
+        printf("gmtcnt=%d \n", gmtcnt);
     stdcnt  = get_long();
     if (debug > 2)
-        printf("stdcnt=%lu \n", stdcnt);
+        printf("stdcnt=%d \n", stdcnt);
     leapcnt = get_long();
     if (debug > 2)
-        printf("leapcnt=%lu \n", leapcnt);
+        printf("leapcnt=%d \n", leapcnt);
     timecnt = get_long();
     if (debug > 2)
-        printf("number of time changes: timecnt=%lu \n", timecnt);
+        printf("number of time changes: timecnt=%d \n", timecnt);
     typecnt = get_long();
     if (debug > 2)
-        printf("number of time change types: typecnt=%lu \n", typecnt);
+        printf("number of time change types: typecnt=%d \n", typecnt);
     charcnt = get_long();
     if (debug > 2)
-        printf("lenght of different timezone names table: charcnt=%lu \n"
+        printf("lenght of different timezone names table: charcnt=%d \n"
                 , charcnt);
     return(0);
 }
 
-void process_local_time_table()
+static void process_local_time_table(void)
 { /* points when time changes */
     time_t tmp;
     int i;
@@ -208,7 +215,7 @@ void process_local_time_table()
     }
 }
 
-void process_local_time_type_table()
+static void process_local_time_type_table(void)
 { /* pointers to table, which explain how time changes */
     unsigned char tmp;
     int i;
@@ -224,7 +231,7 @@ void process_local_time_type_table()
     }
 }
 
-void process_ttinfo_table()
+static void process_ttinfo_table(void)
 { /* table of different time changes = types */
     long tmp;
     unsigned char tmp2, tmp3;
@@ -245,7 +252,7 @@ void process_ttinfo_table()
     }
 }
 
-void process_abbr_table()
+static void process_abbr_table(void)
 {
     unsigned char *tmp;
     int i;
@@ -263,7 +270,7 @@ void process_abbr_table()
     in_head += charcnt;
 }
 
-void process_leap_table()
+static void process_leap_table(void)
 {
     unsigned long tmp, tmp2;
     int i;
@@ -279,7 +286,7 @@ void process_leap_table()
     }
 }
 
-void process_std_table()
+static void process_std_table(void)
 {
     unsigned char tmp;
     int i;
@@ -294,7 +301,7 @@ void process_std_table()
     }
 }
 
-void process_gmt_table()
+static void process_gmt_table(void)
 {
     unsigned char tmp;
     int i;
@@ -311,11 +318,11 @@ void process_gmt_table()
 
 /* go through the contents of the file and find the positions of 
  * needed data. Uses global pointer: in_head */
-int process_file(const char *file_name)
+static int process_file(const char *file_name)
 {
     if (debug > 1)
         printf("\n\nprocess_file: start\n");
-    if (process_header(file_name)) {
+    if (process_header()) {
         printf("File (%s) does not look like tz file. Skipping it.\n"
                 , file_name);
         return(1);
@@ -332,28 +339,28 @@ int process_file(const char *file_name)
     return(0); /* ok */
 }
 
-void create_backup_file(char *out_file)
+static void create_backup_file(char *_out_file)
 {
     char *backup_out_file, backup_ending[]=".old";
-    int out_file_name_len, backup_ending_len, backup_out_file_name_len;
+    size_t out_file_name_len, backup_ending_len, backup_out_file_name_len;
 
-    out_file_name_len = strlen(out_file);
+    out_file_name_len = strlen(_out_file);
     backup_ending_len = strlen(backup_ending);
     backup_out_file_name_len = out_file_name_len + backup_ending_len;
 
     backup_out_file = malloc(backup_out_file_name_len + 1);
-    strncpy(backup_out_file, out_file, out_file_name_len);
+    strncpy(backup_out_file, _out_file, backup_out_file_name_len + 1);
     backup_out_file[out_file_name_len] = '\0';
-    strncat(backup_out_file, backup_ending, backup_ending_len);
+    strncat(backup_out_file, backup_ending, backup_out_file_name_len + 1);
 
-    if (rename(out_file, backup_out_file)) {
+    if (rename(_out_file, backup_out_file)) {
         printf("Error creating backup file %s:\n", backup_out_file);
         perror("\trename");
     }
     free(backup_out_file);
 }
 
-void create_ical_directory(const char *in_file_name)
+static void create_ical_directory(const char *in_file_name)
 {
     char *ical_dir_name;
 
@@ -379,11 +386,11 @@ void create_ical_directory(const char *in_file_name)
         printf("create_ical_directory: end\n");
 }
 
-int create_ical_file(const char *in_file_name)
+static int create_ical_file(const char *in_file_name)
 {
     struct stat out_stat;
     char ical_ending[]=".ics";
-    int in_file_name_len, ical_ending_len, out_file_name_len;
+    size_t in_file_name_len, ical_ending_len, out_file_name_len;
 
     if (debug > 1)
         printf("create_ical_file: start\n");
@@ -395,7 +402,7 @@ int create_ical_file(const char *in_file_name)
         out_file = malloc(out_file_name_len + 1);
         strncpy(out_file, &in_file_name[in_file_base_offset], in_file_name_len);
         out_file[in_file_name_len] = '\0';
-        strncat(out_file, ical_ending, ical_ending_len);
+        strncat(out_file, ical_ending, out_file_name_len + 1);
 
         /* FIXME: it is possible that in_timezone_name and timezone_name
          * do not get any value! Move them outside of this if */
@@ -467,15 +474,15 @@ int create_ical_file(const char *in_file_name)
     return(0);
 }
 
-void write_ical_str(char *data)
+static void write_ical_str(char *data)
 {
-    int len;
+    size_t len;
 
     len = strlen(data);
     fwrite(data, 1, len, ical_file);
 }
 
-void write_ical_header()
+static void write_ical_header(void)
 {
     char *vcalendar = "BEGIN:VCALENDAR\nPRODID:-//Xfce//NONSGML Orage Olson-VTIMEZONE Converter//EN\nVERSION:2.0\n";
     char *vtimezone = "BEGIN:VTIMEZONE\nTZID:/softwarestudio.org/Olson_20011030_5/";
@@ -491,11 +498,11 @@ void write_ical_header()
     write_ical_str(line);
 }
 
-struct ical_timezone_data wit_get_data(int i
+static struct ical_timezone_data wit_get_data(int i
         , struct ical_timezone_data *prev) {
     unsigned long tc_time;
     unsigned int tct_i, abbr_i;
-    struct ical_timezone_data data;
+    struct ical_timezone_data data = {0};
 
     /* get timechange time */
     in_head = begin_timechanges;
@@ -548,7 +555,7 @@ struct ical_timezone_data wit_get_data(int i
  * RDATE == 100
  * no repeat possible == 0
  * */
-int wit_get_repeat_rule(struct ical_timezone_data *prev
+static int wit_get_repeat_rule(struct ical_timezone_data *prev
         , struct ical_timezone_data *cur) {
     int monthdays[12] = {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
     int repeat_rule;
@@ -627,12 +634,11 @@ int wit_get_repeat_rule(struct ical_timezone_data *prev
     return(repeat_rule);
 }
 
-void wit_write_data(int repeat_rule, struct rdate_prev_data **rdate
+static void wit_write_data(int repeat_rule, struct rdate_prev_data **rdate
         , struct ical_timezone_data *first, struct ical_timezone_data *prev
         , struct ical_timezone_data *ical_data)
 {
     char str[100], until_date[31];
-    int len;
     char *dst_begin="BEGIN:DAYLIGHT\n";
     char *dst_end="END:DAYLIGHT\n";
     char *std_begin="BEGIN:STANDARD\n";
@@ -693,25 +699,25 @@ void wit_write_data(int repeat_rule, struct rdate_prev_data **rdate
     else
         write_ical_str(std_begin);
 
-    len = snprintf(str, 30, "TZOFFSETFROM:%+03d%02d\n"
+    snprintf(str, 30, "TZOFFSETFROM:%+03d%02d\n"
             , prev->prev_gmt_offset_hh, prev->prev_gmt_offset_mm);
-    fwrite(str, 1, len, ical_file);
+    fwrite(str, 1, strlen (str), ical_file);
 
-    len = snprintf(str, 30, "TZOFFSETTO:%+03d%02d\n"
+    snprintf(str, 30, "TZOFFSETTO:%+03d%02d\n"
             , prev->gmt_offset_hh, prev->gmt_offset_mm);
-    fwrite(str, 1, len, ical_file);
+    fwrite(str, 1, strlen (str), ical_file);
 
-    len = snprintf(str, 99, "TZNAME:%s\n", prev->tz);
-    fwrite(str, 1, len, ical_file);
+    snprintf(str, 99, "TZNAME:%s\n", prev->tz);
+    fwrite(str, 1, strlen (str), ical_file);
 
-    len = snprintf(str, 30, "DTSTART:%04d%02d%02dT%02d%02d%02d\n"
+    snprintf(str, 99, "DTSTART:%04d%02d%02dT%02d%02d%02d\n"
             , first->start_time.tm_year + 1900
             , first->start_time.tm_mon  + 1
             , first->start_time.tm_mday
             , first->start_time.tm_hour
             , first->start_time.tm_min
             , first->start_time.tm_sec);
-    fwrite(str, 1, len, ical_file);
+    fwrite(str, 1, strlen (str), ical_file);
 
     if (repeat_rule) { /* we had repeating appointment */
         if (repeat_rule < 10) { /* RRULE */
@@ -736,31 +742,31 @@ void wit_write_data(int repeat_rule, struct rdate_prev_data **rdate
                 }
                 until_time.tm_mday = 1;
             }
-            len = snprintf(until_date, 30, "%04d%02d%02dT235959Z"
+            snprintf(until_date, 99, "%04d%02d%02dT235959Z"
                     , until_time.tm_year + 1900
                     , until_time.tm_mon  + 1
                     , until_time.tm_mday);
-            len = snprintf(str, 80
+            snprintf(str, 99
                     , "RRULE:FREQ=YEARLY;BYMONTH=%d;BYDAY=%d%s;UNTIL=%s\n"
                     , first->start_time.tm_mon + 1
                     , repeat_rule
                     , day[first->start_time.tm_wday]
                     , until_date);
-            fwrite(str, 1, len, ical_file);
+            fwrite(str, 1, strlen(str), ical_file);
         }
         else { /* RDATE */
             if (debug > 3)
                 printf("\t\t...RDATE\n");
             for (tmp_data = *rdate; tmp_data ; ) {
                 tmp_prev = tmp_data->data;
-                len = snprintf(str, 30, "RDATE:%04d%02d%02dT%02d%02d%02d\n"
+                snprintf(str, 99, "RDATE:%04d%02d%02dT%02d%02d%02d\n"
                         , tmp_prev.start_time.tm_year + 1900
                         , tmp_prev.start_time.tm_mon  + 1
                         , tmp_prev.start_time.tm_mday
                         , tmp_prev.start_time.tm_hour
                         , tmp_prev.start_time.tm_min
                         , tmp_prev.start_time.tm_sec);
-                fwrite(str, 1, len, ical_file);
+                fwrite(str, 1, strlen (str), ical_file);
 
                 tmp_data2 = tmp_data;
                 tmp_data = tmp_data->next;
@@ -780,7 +786,7 @@ void wit_write_data(int repeat_rule, struct rdate_prev_data **rdate
         write_ical_str(std_end);
 }
 
-void wit_push_to_rdate_queue(struct rdate_prev_data **p_rdate_data
+static void wit_push_to_rdate_queue(struct rdate_prev_data **p_rdate_data
         , struct ical_timezone_data *p_data_prev)
 {
     struct rdate_prev_data *tmp_data = NULL, *tmp_data2 = NULL;
@@ -801,7 +807,7 @@ void wit_push_to_rdate_queue(struct rdate_prev_data **p_rdate_data
     }
 }
 
-void write_ical_timezones()
+static void write_ical_timezones(void)
 {
     int i;
     /* ical_data        contains the just read new record being processed
@@ -815,11 +821,11 @@ void write_ical_timezones()
      *                  repeating groups, it is actually the same than prev.
      *                  */
     struct ical_timezone_data ical_data
-        , ical_data_prev = { {0, 0, 0, 0, 0, 0, 0}, 0, 0, 0, 0, 0, 0, 0, NULL}
-        , data_prev_std = { {0, 0, 0, 0, 0, 0, 0}, 0, 0, 0, 0, 0, 0, 0, NULL}
-        , data_first_std = { {0, 0, 0, 0, 0, 0, 0}, 0, 0, 0, 0, 0, 0, 0, NULL}
-        , data_prev_dst = { {0, 0, 0, 0, 0, 0, 0}, 0, 0, 0, 0, 0, 0, 0, NULL}
-        , data_first_dst = { {0, 0, 0, 0, 0, 0, 0}, 0, 0, 0, 0, 0, 0, 0, NULL};
+        , ical_data_prev = {0}
+        , data_prev_std = {0}
+        , data_first_std = {0}
+        , data_prev_dst = {0}
+        , data_first_dst = {0};
         /* pointers either to data_prev_std and data_first_std
          * or to data_prev_dst and data_first_dst. 
          * These avoid having separate code paths for std and dst */
@@ -1065,7 +1071,7 @@ void write_ical_timezones()
         printf("\tskipping last dst write as dst init has not been done:\n");
 }
 
-void write_ical_ending()
+static void write_ical_ending(void)
 {
     char *end= "END:VTIMEZONE\nEND:VCALENDAR\n";
 
@@ -1074,7 +1080,7 @@ void write_ical_ending()
 
 /* FIXME: need to check that if OUTFILE is given as a parameter,
  * INFILE is not a directory (or make outfile to act like directory also ? */
-int write_ical_file(const char *in_file_name, const struct stat *in_file_stat)
+static int write_ical_file(const char *in_file_name, const struct stat *in_file_stat)
 {
     if (debug > 1)
         printf("***** write_ical_file: start *****\n\n");
@@ -1086,10 +1092,12 @@ int write_ical_file(const char *in_file_name, const struct stat *in_file_stat)
     fclose(ical_file);
     if (debug > 1)
         printf("\n***** write_ical_file: end *****\n\n\n");
+
+    (void)in_file_stat;
     return(0);
 }
 
-void write_parameters(const char *par_file_name)
+static void write_parameters(const char *par_file_name)
 {
     /* FIXME: currently only writing the location of system tz files.
      * It would be good to have a way to influence other parameters also.*/
@@ -1107,7 +1115,7 @@ void write_parameters(const char *par_file_name)
     len = in_file_base_offset + strlen("zoneinfo");
     if (in_file[len-1] == '/')
         len--; /* remove trailing / */
-    if (len <= strlen(in_file)) {
+    if (len <= (int)strlen(in_file)) {
         fwrite(in_file, 1, len, par_file);
     }
     else {
@@ -1155,7 +1163,7 @@ void read_parameters(const char *par_file_name)
 }
 */
 
-int par_version()
+static int par_version(void)
 {
     printf(
         "tz_convert version (Orage utility) %s\n"
@@ -1168,7 +1176,7 @@ int par_version()
     return(1);
 }
 
-int par_help()
+static int par_help(void)
 {
     printf(
         "tz_convert converts operating system timezone (tz) files\n"
@@ -1188,7 +1196,7 @@ int par_help()
     return(1);
 }
 
-int get_parameters_popt(int argc, const char **argv)
+static int get_parameters_popt(int argc, const char **argv)
 {
     int par_type = 0, val, res = 0, i;
     char *tmp_str = NULL;
@@ -1264,9 +1272,13 @@ int get_parameters_popt(int argc, const char **argv)
                 res = val;
                 break;
             case 3:
+                if (in_file)
+                    free(in_file);
                 in_file = strdup(tmp_str);
                 break;
             case 4:
+                if (out_file)
+                    free(out_file);
                 out_file = strdup(tmp_str);
                 break;
             case 5:
@@ -1277,6 +1289,8 @@ int get_parameters_popt(int argc, const char **argv)
                         , ignore_older);
                 break;
             case 7:
+                if (timezone_name)
+                    free(timezone_name);
                 timezone_name = strdup(tmp_str);
                 break;
             case 8:
@@ -1340,7 +1354,7 @@ int get_parameters_popt(int argc, const char **argv)
     return(res);
 }
 
-void add_zone_tabs()
+static void add_zone_tabs(void)
 {
     /* ical index filename is zoneinfo/zones.tab 
      * and os file is zone.tab */
@@ -1350,7 +1364,9 @@ void add_zone_tabs()
     char *ical_zone_buf, *line_end, *buf;
     int offset; /* offset to next timezone in libical zones.tab */
     int before; /* current timezone appears before ours in zones.tab */
-    int len = strlen(timezone_name), buf_len;
+    size_t file_size;
+    size_t buf_len;
+    size_t len = strlen (timezone_name);
 
     if (debug > 1)
         printf("add_zone_tabs: start\n");
@@ -1382,8 +1398,9 @@ void add_zone_tabs()
         return;
     }
 
-    ical_zone_buf = malloc(ical_zone_stat.st_size+1);
-    if (!fread(ical_zone_buf, 1, ical_zone_stat.st_size, ical_zone_tab)
+    file_size = ical_zone_stat.st_size;
+    ical_zone_buf = malloc (file_size + 1);
+    if ((fread(ical_zone_buf, 1, file_size, ical_zone_tab) < file_size)
     && (ferror(ical_zone_tab))) {
         printf("add_zone_tabs: error reading (%s).\n", ical_zone);
         perror("\tfread");
@@ -1391,7 +1408,7 @@ void add_zone_tabs()
         fclose(ical_zone_tab);
         return;
     }
-    ical_zone_buf[ical_zone_stat.st_size] = 0; /* end with null */
+    ical_zone_buf[file_size] = 0; /* end with null */
     if (strstr(ical_zone_buf, timezone_name)) {
         if (debug > 1)
             printf("add_zone_tabs: timezone exists already, returning.\n");
@@ -1412,18 +1429,18 @@ void add_zone_tabs()
     }
     buf_len=len+18+1; /* +1=add \n */
     buf = malloc(buf_len+1); /* +1=add \0 */
-    sprintf(buf, "+0000000 -0000000 %s\n", timezone_name);
+    snprintf(buf, buf_len + 1, "+0000000 -0000000 %s\n", timezone_name);
     if (before) {
         if (fseek(ical_zone_tab, 0l, SEEK_END))
             perror("\tfseek-end");
         else
-            fwrite(buf, 1, buf_len, ical_zone_tab);
+            fwrite(buf, 1, strlen (buf), ical_zone_tab);
     }
     else {
         if (fseek(ical_zone_tab, offset-18, SEEK_SET))
             perror("\tfseek-set");
         else {
-            fwrite(buf, 1, buf_len, ical_zone_tab);
+            fwrite(buf, 1, strlen (buf), ical_zone_tab);
             buf_len = strlen(&ical_zone_buf[offset-18]);
             fwrite(&ical_zone_buf[offset-18], 1, buf_len, ical_zone_tab);
         }
@@ -1437,10 +1454,12 @@ void add_zone_tabs()
 }
 
 /* The main code. This is called once per each file found */
-int file_call(const char *file_name, const struct stat *sb, int flags
+static int file_call(const char *file_name, const struct stat *sb, int flags
         , struct FTW *f)
 {
+#ifdef FTW_ACTIONRETVAL
     int i;
+#endif
 
     if (debug > 1)
         printf("file_call: start\n");
@@ -1513,7 +1532,7 @@ int file_call(const char *file_name, const struct stat *sb, int flags
 }
 
 /* check the parameters and use defaults when possible */
-int check_parameters()
+static int check_parameters(void)
 {
     char *s_tz, *last_tz = NULL, tz[]="/zoneinfo", tz2[]="zoneinfo/";
     int tz_len, i;
@@ -1629,9 +1648,9 @@ int main(int argc, const char **argv)
      * if it run into an error.
      * BSD lacks FTW_ACTIONRETVAL, so we only use it when available. */
 #ifdef FTW_ACTIONRETVAL
-    if (nftw(in_file, file_call, 10, FTW_PHYS | FTW_ACTIONRETVAL) == -1) {
+    if (in_file == NULL || nftw(in_file, file_call, 10, FTW_PHYS | FTW_ACTIONRETVAL) == -1) {
 #else
-    if (nftw(in_file, file_call, 10, FTW_PHYS) == -1) {
+    if (in_file == NULL || nftw(in_file, file_call, 10, FTW_PHYS) == -1) {
 #endif
         perror("nftw error in file handling");
         exit(EXIT_FAILURE);
